Class: Google::Apis::DatamigrationV1::CloudSqlSettings
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::CloudSqlSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Settings for creating a Cloud SQL database instance.
Instance Attribute Summary collapse
-
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is applicable only when the instance state is 'RUNNABLE'.
-
#auto_storage_increase ⇒ Boolean
(also: #auto_storage_increase?)
[default: ON] If you enable this setting, Cloud SQL checks your available storage every 30 seconds.
-
#availability_type ⇒ String
Optional.
-
#cmek_key_name ⇒ String
The KMS key name used for the csql instance.
-
#collation ⇒ String
The Cloud SQL default instance level collation.
-
#data_cache_config ⇒ Google::Apis::DatamigrationV1::DataCacheConfig
Data cache is an optional feature available for Cloud SQL for MySQL Enterprise Plus edition only.
-
#data_disk_provisioned_iops ⇒ Fixnum
Optional.
-
#data_disk_provisioned_throughput ⇒ Fixnum
Optional.
-
#data_disk_size_gb ⇒ Fixnum
The storage capacity available to the database, in GB.
-
#data_disk_type ⇒ String
The type of storage:
PD_SSD(default) orPD_HDDorHYPERDISK_BALANCED. -
#database_flags ⇒ Hash<String,String>
The database flags passed to the Cloud SQL instance at startup.
-
#database_version ⇒ String
The database engine type and version.
-
#database_version_name ⇒ String
Optional.
-
#edition ⇒ String
Optional.
-
#ip_config ⇒ Google::Apis::DatamigrationV1::SqlIpConfig
IP Management configuration.
-
#root_password ⇒ String
Input only.
-
#root_password_set ⇒ Boolean
(also: #root_password_set?)
Output only.
-
#secondary_zone ⇒ String
Optional.
-
#source_id ⇒ String
The Database Migration Service source connection profile ID, in the format:
projects/my_project_name/locations/us-central1/connectionProfiles/ connection_profile_IDCorresponds to the JSON propertysourceId. -
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased.
-
#tier ⇒ String
The tier (or machine type) for this instance, for example:
db-n1-standard-1( MySQL instances) ordb-custom-1-3840(PostgreSQL instances). -
#user_labels ⇒ Hash<String,String>
The resource labels for a Cloud SQL instance to use to annotate any related underlying resources such as Compute Engine VMs.
-
#zone ⇒ String
The Google Cloud Platform zone where your Cloud SQL database instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudSqlSettings
constructor
A new instance of CloudSqlSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudSqlSettings
Returns a new instance of CloudSqlSettings.
750 751 752 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is
applicable only when the instance state is 'RUNNABLE'. Valid values: 'ALWAYS':
The instance is on, and remains so even in the absence of connection requests.
NEVER: The instance is off; it is not activated, even if a connection
request arrives.
Corresponds to the JSON property activationPolicy
608 609 610 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 608 def activation_policy @activation_policy end |
#auto_storage_increase ⇒ Boolean Also known as: auto_storage_increase?
[default: ON] If you enable this setting, Cloud SQL checks your available
storage every 30 seconds. If the available storage falls below a threshold
size, Cloud SQL automatically adds additional storage capacity. If the
available storage repeatedly falls below the threshold size, Cloud SQL
continues to add storage until it reaches the maximum of 30 TB.
Corresponds to the JSON property autoStorageIncrease
617 618 619 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 617 def auto_storage_increase @auto_storage_increase end |
#availability_type ⇒ String
Optional. Availability type. Potential values: * ZONAL: The instance serves
data from only one zone. Outages in that zone affect data availability. *
REGIONAL: The instance can serve data from more than one zone in a region (it
is highly available).
Corresponds to the JSON property availabilityType
626 627 628 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 626 def availability_type @availability_type end |
#cmek_key_name ⇒ String
The KMS key name used for the csql instance.
Corresponds to the JSON property cmekKeyName
631 632 633 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 631 def cmek_key_name @cmek_key_name end |
#collation ⇒ String
The Cloud SQL default instance level collation.
Corresponds to the JSON property collation
636 637 638 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 636 def collation @collation end |
#data_cache_config ⇒ Google::Apis::DatamigrationV1::DataCacheConfig
Data cache is an optional feature available for Cloud SQL for MySQL Enterprise
Plus edition only. For more information on data cache, see Data cache
overview in Cloud SQL
documentation.
Corresponds to the JSON property dataCacheConfig
644 645 646 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 644 def data_cache_config @data_cache_config end |
#data_disk_provisioned_iops ⇒ Fixnum
Optional. Provisioned number of I/O operations per second for the data disk.
This field is only used for hyperdisk-balanced disk types.
Corresponds to the JSON property dataDiskProvisionedIops
650 651 652 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 650 def data_disk_provisioned_iops @data_disk_provisioned_iops end |
#data_disk_provisioned_throughput ⇒ Fixnum
Optional. Provisioned throughput measured in MiB per second for the data disk.
This field is only used for hyperdisk-balanced disk types.
Corresponds to the JSON property dataDiskProvisionedThroughput
656 657 658 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 656 def data_disk_provisioned_throughput @data_disk_provisioned_throughput end |
#data_disk_size_gb ⇒ Fixnum
The storage capacity available to the database, in GB. The minimum (and
default) size is 10GB.
Corresponds to the JSON property dataDiskSizeGb
662 663 664 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 662 def data_disk_size_gb @data_disk_size_gb end |
#data_disk_type ⇒ String
The type of storage: PD_SSD (default) or PD_HDD or HYPERDISK_BALANCED.
Corresponds to the JSON property dataDiskType
667 668 669 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 667 def data_disk_type @data_disk_type end |
#database_flags ⇒ Hash<String,String>
The database flags passed to the Cloud SQL instance at startup. An object
containing a list of "key": value pairs. Example: "name": "wrench", "mass": "
1.3kg", "count": "3".
Corresponds to the JSON property databaseFlags
674 675 676 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 674 def database_flags @database_flags end |
#database_version ⇒ String
The database engine type and version. Deprecated. Use database_version_name
instead.
Corresponds to the JSON property databaseVersion
680 681 682 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 680 def database_version @database_version end |
#database_version_name ⇒ String
Optional. The database engine type and version name.
Corresponds to the JSON property databaseVersionName
685 686 687 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 685 def database_version_name @database_version_name end |
#edition ⇒ String
Optional. The edition of the given Cloud SQL instance.
Corresponds to the JSON property edition
690 691 692 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 690 def edition @edition end |
#ip_config ⇒ Google::Apis::DatamigrationV1::SqlIpConfig
IP Management configuration.
Corresponds to the JSON property ipConfig
695 696 697 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 695 def ip_config @ip_config end |
#root_password ⇒ String
Input only. Initial root password.
Corresponds to the JSON property rootPassword
700 701 702 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 700 def root_password @root_password end |
#root_password_set ⇒ Boolean Also known as: root_password_set?
Output only. Indicates If this connection profile root password is stored.
Corresponds to the JSON property rootPasswordSet
705 706 707 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 705 def root_password_set @root_password_set end |
#secondary_zone ⇒ String
Optional. The Google Cloud Platform zone where the failover Cloud SQL database
instance is located. Used when the Cloud SQL database availability type is
REGIONAL (i.e. multiple zones / highly available).
Corresponds to the JSON property secondaryZone
713 714 715 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 713 def secondary_zone @secondary_zone end |
#source_id ⇒ String
The Database Migration Service source connection profile ID, in the format:
projects/my_project_name/locations/us-central1/connectionProfiles/
connection_profile_ID
Corresponds to the JSON property sourceId
720 721 722 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 720 def source_id @source_id end |
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased. The
default value is 0, which specifies that there is no limit.
Corresponds to the JSON property storageAutoResizeLimit
726 727 728 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 726 def storage_auto_resize_limit @storage_auto_resize_limit end |
#tier ⇒ String
The tier (or machine type) for this instance, for example: db-n1-standard-1 (
MySQL instances) or db-custom-1-3840 (PostgreSQL instances). For more
information, see Cloud SQL Instance Settings.
Corresponds to the JSON property tier
734 735 736 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 734 def tier @tier end |
#user_labels ⇒ Hash<String,String>
The resource labels for a Cloud SQL instance to use to annotate any related
underlying resources such as Compute Engine VMs. An object containing a list
of "key": "value" pairs. Example: "name": "wrench", "mass": "18kg", "count":
"3".
Corresponds to the JSON property userLabels
742 743 744 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 742 def user_labels @user_labels end |
#zone ⇒ String
The Google Cloud Platform zone where your Cloud SQL database instance is
located.
Corresponds to the JSON property zone
748 749 750 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 748 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 755 def update!(**args) @activation_policy = args[:activation_policy] if args.key?(:activation_policy) @auto_storage_increase = args[:auto_storage_increase] if args.key?(:auto_storage_increase) @availability_type = args[:availability_type] if args.key?(:availability_type) @cmek_key_name = args[:cmek_key_name] if args.key?(:cmek_key_name) @collation = args[:collation] if args.key?(:collation) @data_cache_config = args[:data_cache_config] if args.key?(:data_cache_config) @data_disk_provisioned_iops = args[:data_disk_provisioned_iops] if args.key?(:data_disk_provisioned_iops) @data_disk_provisioned_throughput = args[:data_disk_provisioned_throughput] if args.key?(:data_disk_provisioned_throughput) @data_disk_size_gb = args[:data_disk_size_gb] if args.key?(:data_disk_size_gb) @data_disk_type = args[:data_disk_type] if args.key?(:data_disk_type) @database_flags = args[:database_flags] if args.key?(:database_flags) @database_version = args[:database_version] if args.key?(:database_version) @database_version_name = args[:database_version_name] if args.key?(:database_version_name) @edition = args[:edition] if args.key?(:edition) @ip_config = args[:ip_config] if args.key?(:ip_config) @root_password = args[:root_password] if args.key?(:root_password) @root_password_set = args[:root_password_set] if args.key?(:root_password_set) @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone) @source_id = args[:source_id] if args.key?(:source_id) @storage_auto_resize_limit = args[:storage_auto_resize_limit] if args.key?(:storage_auto_resize_limit) @tier = args[:tier] if args.key?(:tier) @user_labels = args[:user_labels] if args.key?(:user_labels) @zone = args[:zone] if args.key?(:zone) end |