Class: Google::Apis::DatamigrationV1::ConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A connection profile definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionProfile

Returns a new instance of ConnectionProfile.



1081
1082
1083
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alloydbGoogle::Apis::DatamigrationV1::AlloyDbConnectionProfile

Specifies required connection parameters, and the parameters required to create an AlloyDB destination cluster. Corresponds to the JSON property alloydb



983
984
985
# File 'lib/google/apis/datamigration_v1/classes.rb', line 983

def alloydb
  @alloydb
end

#cloudsqlGoogle::Apis::DatamigrationV1::CloudSqlConnectionProfile

Specifies required connection parameters, and, optionally, the parameters required to create a Cloud SQL destination database instance. Corresponds to the JSON property cloudsql



989
990
991
# File 'lib/google/apis/datamigration_v1/classes.rb', line 989

def cloudsql
  @cloudsql
end

#create_timeString

Output only. The timestamp when the resource was created. A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01: 23.045123456Z". Corresponds to the JSON property createTime

Returns:

  • (String)


996
997
998
# File 'lib/google/apis/datamigration_v1/classes.rb', line 996

def create_time
  @create_time
end

#display_nameString

The connection profile display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1001
1002
1003
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1001

def display_name
  @display_name
end

#errorGoogle::Apis::DatamigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1011
1012
1013
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1011

def error
  @error
end

#labelsHash<String,String>

The resource labels for connection profile to use to annotate any related underlying resources such as Compute Engine VMs. An object containing a list of "key": "value" pairs. Example: "name": "wrench", "mass": "1.3kg", "count" : "3". Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1019
1020
1021
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1019

def labels
  @labels
end

#mysqlGoogle::Apis::DatamigrationV1::MySqlConnectionProfile

Specifies connection parameters required specifically for MySQL databases. Corresponds to the JSON property mysql



1024
1025
1026
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1024

def mysql
  @mysql
end

#nameString

The name of this connection profile resource in the form of projects/project/ locations/location/connectionProfiles/connectionProfile. Corresponds to the JSON property name

Returns:

  • (String)


1030
1031
1032
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1030

def name
  @name
end

#oracleGoogle::Apis::DatamigrationV1::OracleConnectionProfile

Specifies connection parameters required specifically for Oracle databases. Corresponds to the JSON property oracle



1035
1036
1037
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1035

def oracle
  @oracle
end

#postgresqlGoogle::Apis::DatamigrationV1::PostgreSqlConnectionProfile

Specifies connection parameters required specifically for PostgreSQL databases. Corresponds to the JSON property postgresql



1040
1041
1042
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1040

def postgresql
  @postgresql
end

#providerString

The database provider. Corresponds to the JSON property provider

Returns:

  • (String)


1045
1046
1047
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1045

def provider
  @provider
end

#roleString

Optional. The connection profile role. Corresponds to the JSON property role

Returns:

  • (String)


1050
1051
1052
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1050

def role
  @role
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1055
1056
1057
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1055

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1061
1062
1063
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1061

def satisfies_pzs
  @satisfies_pzs
end

#sqlserverGoogle::Apis::DatamigrationV1::SqlServerConnectionProfile

Specifies connection parameters required specifically for SQL Server databases. Corresponds to the JSON property sqlserver



1067
1068
1069
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1067

def sqlserver
  @sqlserver
end

#stateString

The current connection profile state (e.g. DRAFT, READY, or FAILED). Corresponds to the JSON property state

Returns:

  • (String)


1072
1073
1074
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1072

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was last updated. A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01: 23.045123456Z". Corresponds to the JSON property updateTime

Returns:

  • (String)


1079
1080
1081
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1079

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1086

def update!(**args)
  @alloydb = args[:alloydb] if args.key?(:alloydb)
  @cloudsql = args[:cloudsql] if args.key?(:cloudsql)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @mysql = args[:mysql] if args.key?(:mysql)
  @name = args[:name] if args.key?(:name)
  @oracle = args[:oracle] if args.key?(:oracle)
  @postgresql = args[:postgresql] if args.key?(:postgresql)
  @provider = args[:provider] if args.key?(:provider)
  @role = args[:role] if args.key?(:role)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @sqlserver = args[:sqlserver] if args.key?(:sqlserver)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end