Class: Google::Apis::DatamigrationV1::DatabaseEntity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::DatabaseEntity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
The base entity type for all the database related entities. The message contains the entity name, the name of its parent, the entity type, and the specific details per entity type.
Instance Attribute Summary collapse
-
#database ⇒ Google::Apis::DatamigrationV1::DatabaseInstanceEntity
DatabaseInstance acts as a parent entity to other database entities.
-
#database_function ⇒ Google::Apis::DatamigrationV1::FunctionEntity
Function's parent is a schema.
-
#database_package ⇒ Google::Apis::DatamigrationV1::PackageEntity
Package's parent is a schema.
-
#entity_ddl ⇒ Array<Google::Apis::DatamigrationV1::EntityDdl>
Details about the entity DDL script.
-
#entity_type ⇒ String
The type of the database entity (table, view, index, ...).
-
#issues ⇒ Array<Google::Apis::DatamigrationV1::EntityIssue>
Details about the various issues found for the entity.
-
#mappings ⇒ Array<Google::Apis::DatamigrationV1::EntityMapping>
Details about entity mappings.
-
#materialized_view ⇒ Google::Apis::DatamigrationV1::MaterializedViewEntity
MaterializedView's parent is a schema.
-
#parent_entity ⇒ String
The full name of the parent entity (e.g. schema name).
-
#schema ⇒ Google::Apis::DatamigrationV1::SchemaEntity
Schema typically has no parent entity, but can have a parent entity DatabaseInstance (for database engines which support it).
-
#sequence ⇒ Google::Apis::DatamigrationV1::SequenceEntity
Sequence's parent is a schema.
-
#short_name ⇒ String
The short name (e.g. table name) of the entity.
-
#stored_procedure ⇒ Google::Apis::DatamigrationV1::StoredProcedureEntity
Stored procedure's parent is a schema.
-
#synonym ⇒ Google::Apis::DatamigrationV1::SynonymEntity
Synonym's parent is a schema.
-
#table ⇒ Google::Apis::DatamigrationV1::TableEntity
Table's parent is a schema.
-
#tree ⇒ String
The type of tree the entity belongs to.
-
#udt ⇒ Google::Apis::DatamigrationV1::UdtEntity
UDT's parent is a schema.
-
#view ⇒ Google::Apis::DatamigrationV1::ViewEntity
View's parent is a schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseEntity
constructor
A new instance of DatabaseEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseEntity
Returns a new instance of DatabaseEntity.
1523 1524 1525 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ Google::Apis::DatamigrationV1::DatabaseInstanceEntity
DatabaseInstance acts as a parent entity to other database entities.
Corresponds to the JSON property database
1427 1428 1429 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1427 def database @database end |
#database_function ⇒ Google::Apis::DatamigrationV1::FunctionEntity
Function's parent is a schema.
Corresponds to the JSON property databaseFunction
1432 1433 1434 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1432 def database_function @database_function end |
#database_package ⇒ Google::Apis::DatamigrationV1::PackageEntity
Package's parent is a schema.
Corresponds to the JSON property databasePackage
1437 1438 1439 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1437 def database_package @database_package end |
#entity_ddl ⇒ Array<Google::Apis::DatamigrationV1::EntityDdl>
Details about the entity DDL script. Multiple DDL scripts are provided for
child entities such as a table entity will have one DDL for the table with
additional DDLs for each index, constraint and such.
Corresponds to the JSON property entityDdl
1444 1445 1446 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1444 def entity_ddl @entity_ddl end |
#entity_type ⇒ String
The type of the database entity (table, view, index, ...).
Corresponds to the JSON property entityType
1449 1450 1451 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1449 def entity_type @entity_type end |
#issues ⇒ Array<Google::Apis::DatamigrationV1::EntityIssue>
Details about the various issues found for the entity.
Corresponds to the JSON property issues
1454 1455 1456 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1454 def issues @issues end |
#mappings ⇒ Array<Google::Apis::DatamigrationV1::EntityMapping>
Details about entity mappings. For source tree entities, this holds the draft
entities which were generated by the mapping rules. For draft tree entities,
this holds the source entities which were converted to form the draft entity.
Destination entities will have no mapping details.
Corresponds to the JSON property mappings
1462 1463 1464 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1462 def mappings @mappings end |
#materialized_view ⇒ Google::Apis::DatamigrationV1::MaterializedViewEntity
MaterializedView's parent is a schema.
Corresponds to the JSON property materializedView
1467 1468 1469 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1467 def materialized_view @materialized_view end |
#parent_entity ⇒ String
The full name of the parent entity (e.g. schema name).
Corresponds to the JSON property parentEntity
1472 1473 1474 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1472 def parent_entity @parent_entity end |
#schema ⇒ Google::Apis::DatamigrationV1::SchemaEntity
Schema typically has no parent entity, but can have a parent entity
DatabaseInstance (for database engines which support it). For some database
engines, the terms schema and user can be used interchangeably when they refer
to a namespace or a collection of other database entities. Can store
additional information which is schema specific.
Corresponds to the JSON property schema
1481 1482 1483 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1481 def schema @schema end |
#sequence ⇒ Google::Apis::DatamigrationV1::SequenceEntity
Sequence's parent is a schema.
Corresponds to the JSON property sequence
1486 1487 1488 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1486 def sequence @sequence end |
#short_name ⇒ String
The short name (e.g. table name) of the entity.
Corresponds to the JSON property shortName
1491 1492 1493 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1491 def short_name @short_name end |
#stored_procedure ⇒ Google::Apis::DatamigrationV1::StoredProcedureEntity
Stored procedure's parent is a schema.
Corresponds to the JSON property storedProcedure
1496 1497 1498 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1496 def stored_procedure @stored_procedure end |
#synonym ⇒ Google::Apis::DatamigrationV1::SynonymEntity
Synonym's parent is a schema.
Corresponds to the JSON property synonym
1501 1502 1503 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1501 def synonym @synonym end |
#table ⇒ Google::Apis::DatamigrationV1::TableEntity
Table's parent is a schema.
Corresponds to the JSON property table
1506 1507 1508 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1506 def table @table end |
#tree ⇒ String
The type of tree the entity belongs to.
Corresponds to the JSON property tree
1511 1512 1513 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1511 def tree @tree end |
#udt ⇒ Google::Apis::DatamigrationV1::UdtEntity
UDT's parent is a schema.
Corresponds to the JSON property udt
1516 1517 1518 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1516 def udt @udt end |
#view ⇒ Google::Apis::DatamigrationV1::ViewEntity
View's parent is a schema.
Corresponds to the JSON property view
1521 1522 1523 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1521 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1528 def update!(**args) @database = args[:database] if args.key?(:database) @database_function = args[:database_function] if args.key?(:database_function) @database_package = args[:database_package] if args.key?(:database_package) @entity_ddl = args[:entity_ddl] if args.key?(:entity_ddl) @entity_type = args[:entity_type] if args.key?(:entity_type) @issues = args[:issues] if args.key?(:issues) @mappings = args[:mappings] if args.key?(:mappings) @materialized_view = args[:materialized_view] if args.key?(:materialized_view) @parent_entity = args[:parent_entity] if args.key?(:parent_entity) @schema = args[:schema] if args.key?(:schema) @sequence = args[:sequence] if args.key?(:sequence) @short_name = args[:short_name] if args.key?(:short_name) @stored_procedure = args[:stored_procedure] if args.key?(:stored_procedure) @synonym = args[:synonym] if args.key?(:synonym) @table = args[:table] if args.key?(:table) @tree = args[:tree] if args.key?(:tree) @udt = args[:udt] if args.key?(:udt) @view = args[:view] if args.key?(:view) end |