Class: Google::Apis::DatamigrationV1::EntityDdl
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::EntityDdl
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
A single DDL statement for a specific entity
Instance Attribute Summary collapse
-
#ddl ⇒ String
The actual ddl code.
-
#ddl_kind ⇒ String
The DDL Kind selected for apply, or UNSPECIFIED if the entity wasn't converted yet.
-
#ddl_type ⇒ String
Type of DDL (Create, Alter).
-
#edited_ddl_kind ⇒ String
If ddl_kind is USER_EDIT, this holds the DDL kind of the original content - DETERMINISTIC or AI.
-
#entity ⇒ String
The name of the database entity the ddl refers to.
-
#entity_type ⇒ String
The entity type (if the DDL is for a sub entity).
-
#issue_id ⇒ Array<String>
EntityIssues found for this ddl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntityDdl
constructor
A new instance of EntityDdl.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntityDdl
Returns a new instance of EntityDdl.
1781 1782 1783 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ddl ⇒ String
The actual ddl code.
Corresponds to the JSON property ddl
1747 1748 1749 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1747 def ddl @ddl end |
#ddl_kind ⇒ String
The DDL Kind selected for apply, or UNSPECIFIED if the entity wasn't converted
yet.
Corresponds to the JSON property ddlKind
1753 1754 1755 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1753 def ddl_kind @ddl_kind end |
#ddl_type ⇒ String
Type of DDL (Create, Alter).
Corresponds to the JSON property ddlType
1758 1759 1760 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1758 def ddl_type @ddl_type end |
#edited_ddl_kind ⇒ String
If ddl_kind is USER_EDIT, this holds the DDL kind of the original content -
DETERMINISTIC or AI. Otherwise, this is DDL_KIND_UNSPECIFIED.
Corresponds to the JSON property editedDdlKind
1764 1765 1766 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1764 def edited_ddl_kind @edited_ddl_kind end |
#entity ⇒ String
The name of the database entity the ddl refers to.
Corresponds to the JSON property entity
1769 1770 1771 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1769 def entity @entity end |
#entity_type ⇒ String
The entity type (if the DDL is for a sub entity).
Corresponds to the JSON property entityType
1774 1775 1776 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1774 def entity_type @entity_type end |
#issue_id ⇒ Array<String>
EntityIssues found for this ddl.
Corresponds to the JSON property issueId
1779 1780 1781 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1779 def issue_id @issue_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1786 def update!(**args) @ddl = args[:ddl] if args.key?(:ddl) @ddl_kind = args[:ddl_kind] if args.key?(:ddl_kind) @ddl_type = args[:ddl_type] if args.key?(:ddl_type) @edited_ddl_kind = args[:edited_ddl_kind] if args.key?(:edited_ddl_kind) @entity = args[:entity] if args.key?(:entity) @entity_type = args[:entity_type] if args.key?(:entity_type) @issue_id = args[:issue_id] if args.key?(:issue_id) end |