Class: Google::Apis::DatamigrationV1::EntityMapping
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::EntityMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Details of the mappings of a database entity.
Instance Attribute Summary collapse
-
#draft_entity ⇒ String
Target entity full name.
-
#draft_type ⇒ String
Type of draft entity.
-
#mapping_log ⇒ Array<Google::Apis::DatamigrationV1::EntityMappingLogEntry>
Entity mapping log entries.
-
#source_entity ⇒ String
Source entity full name.
-
#source_type ⇒ String
Type of source entity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntityMapping
constructor
A new instance of EntityMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntityMapping
Returns a new instance of EntityMapping.
1938 1939 1940 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#draft_entity ⇒ String
Target entity full name. The draft entity can also include a column, index or
constraint using the same naming notation schema.table.column.
Corresponds to the JSON property draftEntity
1911 1912 1913 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1911 def draft_entity @draft_entity end |
#draft_type ⇒ String
Type of draft entity.
Corresponds to the JSON property draftType
1916 1917 1918 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1916 def draft_type @draft_type end |
#mapping_log ⇒ Array<Google::Apis::DatamigrationV1::EntityMappingLogEntry>
Entity mapping log entries. Multiple rules can be effective and contribute
changes to a converted entity, such as a rule can handle the entity name,
another rule can handle an entity type. In addition, rules which did not
change the entity are also logged along with the reason preventing them to do
so.
Corresponds to the JSON property mappingLog
1925 1926 1927 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1925 def mapping_log @mapping_log end |
#source_entity ⇒ String
Source entity full name. The source entity can also be a column, index or
constraint using the same naming notation schema.table.column.
Corresponds to the JSON property sourceEntity
1931 1932 1933 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1931 def source_entity @source_entity end |
#source_type ⇒ String
Type of source entity.
Corresponds to the JSON property sourceType
1936 1937 1938 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1936 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1943 def update!(**args) @draft_entity = args[:draft_entity] if args.key?(:draft_entity) @draft_type = args[:draft_type] if args.key?(:draft_type) @mapping_log = args[:mapping_log] if args.key?(:mapping_log) @source_entity = args[:source_entity] if args.key?(:source_entity) @source_type = args[:source_type] if args.key?(:source_type) end |