Class: Google::Apis::DatamigrationV1::GenerateTcpProxyScriptRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Request message for 'GenerateTcpProxyScript' request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateTcpProxyScriptRequest

Returns a new instance of GenerateTcpProxyScriptRequest.



2203
2204
2205
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#vm_machine_typeString

Required. The type of the Compute instance that will host the proxy. Corresponds to the JSON property vmMachineType

Returns:

  • (String)


2180
2181
2182
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2180

def vm_machine_type
  @vm_machine_type
end

#vm_nameString

Required. The name of the Compute instance that will host the proxy. Corresponds to the JSON property vmName

Returns:

  • (String)


2185
2186
2187
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2185

def vm_name
  @vm_name
end

#vm_subnetString

Required. The name of the subnet the Compute instance will use for private connectivity. Must be supplied in the form of projects/project/regions/ region/subnetworks/subnetwork. Note: the region for the subnet must match the Compute instance region. Corresponds to the JSON property vmSubnet

Returns:

  • (String)


2193
2194
2195
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2193

def vm_subnet
  @vm_subnet
end

#vm_zoneString

Optional. The Google Cloud Platform zone to create the VM in. The fully qualified name of the zone must be specified, including the region name, for example "us-central1-b". If not specified, uses the "-b" zone of the destination Connection Profile's region. Corresponds to the JSON property vmZone

Returns:

  • (String)


2201
2202
2203
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2201

def vm_zone
  @vm_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2208
2209
2210
2211
2212
2213
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2208

def update!(**args)
  @vm_machine_type = args[:vm_machine_type] if args.key?(:vm_machine_type)
  @vm_name = args[:vm_name] if args.key?(:vm_name)
  @vm_subnet = args[:vm_subnet] if args.key?(:vm_subnet)
  @vm_zone = args[:vm_zone] if args.key?(:vm_zone)
end