Class: Google::Apis::DatamigrationV1::IndexEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Index is not used as an independent entity, it is retrieved as part of a Table entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexEntity

Returns a new instance of IndexEntity.



2574
2575
2576
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_featuresHash<String,Object>

Custom engine specific features. Corresponds to the JSON property customFeatures

Returns:

  • (Hash<String,Object>)


2541
2542
2543
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2541

def custom_features
  @custom_features
end

#nameString

The name of the index. Corresponds to the JSON property name

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2546

def name
  @name
end

#table_columnsArray<String>

Table columns used as part of the Index, for example B-TREE index should list the columns which constitutes the index. Corresponds to the JSON property tableColumns

Returns:

  • (Array<String>)


2552
2553
2554
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2552

def table_columns
  @table_columns
end

#table_columns_descendingArray<Boolean>

For each table_column, mark whether it's sorting order is ascending (false) or descending (true). If no value is defined, assume all columns are sorted in ascending order. Otherwise, the number of items must match that of table_columns with each value specifying the direction of the matched column by its index. Corresponds to the JSON property tableColumnsDescending

Returns:

  • (Array<Boolean>)


2561
2562
2563
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2561

def table_columns_descending
  @table_columns_descending
end

#typeString

Type of index, for example B-TREE. Corresponds to the JSON property type

Returns:

  • (String)


2566
2567
2568
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2566

def type
  @type
end

#uniqueBoolean Also known as: unique?

Boolean value indicating whether the index is unique. Corresponds to the JSON property unique

Returns:

  • (Boolean)


2571
2572
2573
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2571

def unique
  @unique
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2579
2580
2581
2582
2583
2584
2585
2586
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2579

def update!(**args)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @name = args[:name] if args.key?(:name)
  @table_columns = args[:table_columns] if args.key?(:table_columns)
  @table_columns_descending = args[:table_columns_descending] if args.key?(:table_columns_descending)
  @type = args[:type] if args.key?(:type)
  @unique = args[:unique] if args.key?(:unique)
end