Class: Google::Apis::DatamigrationV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



2669
2670
2671
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2654
2655
2656
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2654

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DatamigrationV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



2659
2660
2661
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2659

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2667
2668
2669
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2667

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2674
2675
2676
2677
2678
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2674

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end