Class: Google::Apis::DatamigrationV1::MultiColumnDatatypeChange
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::MultiColumnDatatypeChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Options to configure rule type MultiColumnDatatypeChange. The rule is used to change the data type and associated properties of multiple columns at once. The rule filter field can refer to one or more entities. The rule scope can be one of:Column. This rule requires additional filters to be specified beyond the basic rule filter field, which is the source data type, but the rule supports additional filtering capabilities such as the minimum and maximum field length. All additional filters which are specified are required to be met in order for the rule to be applied (logical AND between the fields).
Instance Attribute Summary collapse
-
#custom_features ⇒ Hash<String,Object>
Optional.
-
#new_data_type ⇒ String
Required.
-
#override_fractional_seconds_precision ⇒ Fixnum
Optional.
-
#override_length ⇒ Fixnum
Optional.
-
#override_precision ⇒ Fixnum
Optional.
-
#override_scale ⇒ Fixnum
Optional.
-
#source_data_type_filter ⇒ String
Required.
-
#source_numeric_filter ⇒ Google::Apis::DatamigrationV1::SourceNumericFilter
Filter for fixed point number data types such as NUMERIC/NUMBER Corresponds to the JSON property
sourceNumericFilter. -
#source_text_filter ⇒ Google::Apis::DatamigrationV1::SourceTextFilter
Filter for text-based data types like varchar.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiColumnDatatypeChange
constructor
A new instance of MultiColumnDatatypeChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiColumnDatatypeChange
Returns a new instance of MultiColumnDatatypeChange.
3778 3779 3780 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_features ⇒ Hash<String,Object>
Optional. Custom engine specific features.
Corresponds to the JSON property customFeatures
3731 3732 3733 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3731 def custom_features @custom_features end |
#new_data_type ⇒ String
Required. New data type.
Corresponds to the JSON property newDataType
3736 3737 3738 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3736 def new_data_type @new_data_type end |
#override_fractional_seconds_precision ⇒ Fixnum
Optional. Column fractional seconds precision - used only for timestamp based
datatypes - if not specified and relevant uses the source column fractional
seconds precision.
Corresponds to the JSON property overrideFractionalSecondsPrecision
3743 3744 3745 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3743 def override_fractional_seconds_precision @override_fractional_seconds_precision end |
#override_length ⇒ Fixnum
Optional. Column length - e.g. varchar (50) - if not specified and relevant
uses the source column length.
Corresponds to the JSON property overrideLength
3749 3750 3751 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3749 def override_length @override_length end |
#override_precision ⇒ Fixnum
Optional. Column precision - when relevant - if not specified and relevant
uses the source column precision.
Corresponds to the JSON property overridePrecision
3755 3756 3757 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3755 def override_precision @override_precision end |
#override_scale ⇒ Fixnum
Optional. Column scale - when relevant - if not specified and relevant uses
the source column scale.
Corresponds to the JSON property overrideScale
3761 3762 3763 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3761 def override_scale @override_scale end |
#source_data_type_filter ⇒ String
Required. Filter on source data type.
Corresponds to the JSON property sourceDataTypeFilter
3766 3767 3768 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3766 def source_data_type_filter @source_data_type_filter end |
#source_numeric_filter ⇒ Google::Apis::DatamigrationV1::SourceNumericFilter
Filter for fixed point number data types such as NUMERIC/NUMBER
Corresponds to the JSON property sourceNumericFilter
3771 3772 3773 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3771 def source_numeric_filter @source_numeric_filter end |
#source_text_filter ⇒ Google::Apis::DatamigrationV1::SourceTextFilter
Filter for text-based data types like varchar.
Corresponds to the JSON property sourceTextFilter
3776 3777 3778 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3776 def source_text_filter @source_text_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3783 def update!(**args) @custom_features = args[:custom_features] if args.key?(:custom_features) @new_data_type = args[:new_data_type] if args.key?(:new_data_type) @override_fractional_seconds_precision = args[:override_fractional_seconds_precision] if args.key?(:override_fractional_seconds_precision) @override_length = args[:override_length] if args.key?(:override_length) @override_precision = args[:override_precision] if args.key?(:override_precision) @override_scale = args[:override_scale] if args.key?(:override_scale) @source_data_type_filter = args[:source_data_type_filter] if args.key?(:source_data_type_filter) @source_numeric_filter = args[:source_numeric_filter] if args.key?(:source_numeric_filter) @source_text_filter = args[:source_text_filter] if args.key?(:source_text_filter) end |