Class: Google::Apis::DatamigrationV1::MultiEntityRename

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Options to configure rule type MultiEntityRename. The rule is used to rename multiple entities. The rule filter field can refer to one or more entities. The rule scope can be one of: Database, Schema, Table, Column, Constraint, Index, View, Function, Stored Procedure, Materialized View, Sequence, UDT

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiEntityRename

Returns a new instance of MultiEntityRename.



3819
3820
3821
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_name_patternString

Optional. The pattern used to generate the new entity's name. This pattern must include the characters 'name', which will be replaced with the name of the original entity. For example, the pattern 't_name' for an entity name jobs would be converted to 't_jobs'. If unspecified, the default value for this field is 'name' Corresponds to the JSON property newNamePattern

Returns:

  • (String)


3810
3811
3812
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3810

def new_name_pattern
  @new_name_pattern
end

#source_name_transformationString

Optional. Additional transformation that can be done on the source entity name before it is being used by the new_name_pattern, for example lower case. If no transformation is desired, use NO_TRANSFORMATION Corresponds to the JSON property sourceNameTransformation

Returns:

  • (String)


3817
3818
3819
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3817

def source_name_transformation
  @source_name_transformation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3824
3825
3826
3827
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3824

def update!(**args)
  @new_name_pattern = args[:new_name_pattern] if args.key?(:new_name_pattern)
  @source_name_transformation = args[:source_name_transformation] if args.key?(:source_name_transformation)
end