Class: Google::Apis::DatamigrationV1::OracleSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Configuration for Oracle as a source in a migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleSourceConfig

Returns a new instance of OracleSourceConfig.



4130
4131
4132
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binary_log_parserGoogle::Apis::DatamigrationV1::BinaryLogParser

Configuration to use Binary Log Parser CDC technique. Corresponds to the JSON property binaryLogParser



4100
4101
4102
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4100

def binary_log_parser
  @binary_log_parser
end

#cdc_start_positionFixnum

Optional. The schema change number (SCN) to start CDC data migration from. Corresponds to the JSON property cdcStartPosition

Returns:

  • (Fixnum)


4105
4106
4107
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4105

def cdc_start_position
  @cdc_start_position
end

#log_minerGoogle::Apis::DatamigrationV1::LogMiner

Configuration to use LogMiner CDC method. Corresponds to the JSON property logMiner



4110
4111
4112
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4110

def log_miner
  @log_miner
end

#max_concurrent_cdc_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for CDC phase. Corresponds to the JSON property maxConcurrentCdcConnections

Returns:

  • (Fixnum)


4116
4117
4118
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4116

def max_concurrent_cdc_connections
  @max_concurrent_cdc_connections
end

#max_concurrent_full_dump_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for full dump phase. Corresponds to the JSON property maxConcurrentFullDumpConnections

Returns:

  • (Fixnum)


4122
4123
4124
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4122

def max_concurrent_full_dump_connections
  @max_concurrent_full_dump_connections
end

#skip_full_dumpBoolean Also known as: skip_full_dump?

Optional. Whether to skip full dump or not. Corresponds to the JSON property skipFullDump

Returns:

  • (Boolean)


4127
4128
4129
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4127

def skip_full_dump
  @skip_full_dump
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4135
4136
4137
4138
4139
4140
4141
4142
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4135

def update!(**args)
  @binary_log_parser = args[:binary_log_parser] if args.key?(:binary_log_parser)
  @cdc_start_position = args[:cdc_start_position] if args.key?(:cdc_start_position)
  @log_miner = args[:log_miner] if args.key?(:log_miner)
  @max_concurrent_cdc_connections = args[:max_concurrent_cdc_connections] if args.key?(:max_concurrent_cdc_connections)
  @max_concurrent_full_dump_connections = args[:max_concurrent_full_dump_connections] if args.key?(:max_concurrent_full_dump_connections)
  @skip_full_dump = args[:skip_full_dump] if args.key?(:skip_full_dump)
end