Class: Google::Apis::DatamigrationV1::OracleToPostgresConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Configuration for heterogeneous Oracle to Cloud SQL for PostgreSQL and ** Oracle to AlloyDB for PostgreSQL** migrations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleToPostgresConfig

Returns a new instance of OracleToPostgresConfig.



4160
4161
4162
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#oracle_source_configGoogle::Apis::DatamigrationV1::OracleSourceConfig

Configuration for Oracle as a source in a migration. Corresponds to the JSON property oracleSourceConfig



4153
4154
4155
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4153

def oracle_source_config
  @oracle_source_config
end

#postgres_destination_configGoogle::Apis::DatamigrationV1::PostgresDestinationConfig

Configuration for Postgres as a destination in a migration. Corresponds to the JSON property postgresDestinationConfig



4158
4159
4160
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4158

def postgres_destination_config
  @postgres_destination_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4165
4166
4167
4168
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4165

def update!(**args)
  @oracle_source_config = args[:oracle_source_config] if args.key?(:oracle_source_config)
  @postgres_destination_config = args[:postgres_destination_config] if args.key?(:postgres_destination_config)
end