Class: Google::Apis::DatamigrationV1::PostgresToSqlServerConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::PostgresToSqlServerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Configuration for heterogeneous failback migrations from PostgreSQL to SQL Server.
Instance Attribute Summary collapse
-
#postgres_source_config ⇒ Google::Apis::DatamigrationV1::PostgresSourceConfig
Configuration for Postgres as a source in a migration.
-
#sqlserver_destination_config ⇒ Google::Apis::DatamigrationV1::SqlServerDestinationConfig
Configuration for SQL Server as a destination in a migration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostgresToSqlServerConfig
constructor
A new instance of PostgresToSqlServerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PostgresToSqlServerConfig
Returns a new instance of PostgresToSqlServerConfig.
4524 4525 4526 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4524 def initialize(**args) update!(**args) end |
Instance Attribute Details
#postgres_source_config ⇒ Google::Apis::DatamigrationV1::PostgresSourceConfig
Configuration for Postgres as a source in a migration.
Corresponds to the JSON property postgresSourceConfig
4517 4518 4519 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4517 def postgres_source_config @postgres_source_config end |
#sqlserver_destination_config ⇒ Google::Apis::DatamigrationV1::SqlServerDestinationConfig
Configuration for SQL Server as a destination in a migration.
Corresponds to the JSON property sqlserverDestinationConfig
4522 4523 4524 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4522 def sqlserver_destination_config @sqlserver_destination_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4529 4530 4531 4532 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4529 def update!(**args) @postgres_source_config = args[:postgres_source_config] if args.key?(:postgres_source_config) @sqlserver_destination_config = args[:sqlserver_destination_config] if args.key?(:sqlserver_destination_config) end |