Class: Google::Apis::DatamigrationV1::PreconditionFailureViolation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A message type used to describe a single precondition failure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreconditionFailureViolation

Returns a new instance of PreconditionFailureViolation.



4648
4649
4650
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of how the precondition failed. Developers can use this description to understand how to fix the failure. For example: "Terms of service not accepted". Corresponds to the JSON property description

Returns:

  • (String)


4632
4633
4634
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4632

def description
  @description
end

#subjectString

The subject, relative to the type, that failed. For example, "google.com/cloud" relative to the "TOS" type would indicate which terms of service is being referenced. Corresponds to the JSON property subject

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4639

def subject
  @subject
end

#typeString

The type of PreconditionFailure. We recommend using a service-specific enum type to define the supported precondition violation subjects. For example, " TOS" for "Terms of Service violation". Corresponds to the JSON property type

Returns:

  • (String)


4646
4647
4648
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4646

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4653
4654
4655
4656
4657
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4653

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @subject = args[:subject] if args.key?(:subject)
  @type = args[:type] if args.key?(:type)
end