Class: Google::Apis::DatamigrationV1::ResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Describes the resource that is being accessed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceInfo

Returns a new instance of ResourceInfo.



5005
5006
5007
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Describes what error is encountered when accessing this resource. For example, updating a cloud project may require the writer permission on the developer console project. Corresponds to the JSON property description

Returns:

  • (String)


4984
4985
4986
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4984

def description
  @description
end

#ownerString

The owner of the resource (optional). For example, "user:" or "project:". Corresponds to the JSON property owner

Returns:

  • (String)


4989
4990
4991
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4989

def owner
  @owner
end

#resource_nameString

The name of the resource being accessed. For example, a shared calendar name: " example.com_4fghdhgsrgh@group.calendar.google.com", if the current error is google.rpc.Code.PERMISSION_DENIED. Corresponds to the JSON property resourceName

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4996

def resource_name
  @resource_name
end

#resource_typeString

A name for the type of resource being accessed, e.g. "sql table", "cloud storage bucket", "file", "Google calendar"; or the type URL of the resource: e. g. "type.googleapis.com/google.pubsub.v1.Topic". Corresponds to the JSON property resourceType

Returns:

  • (String)


5003
5004
5005
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5003

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5010
5011
5012
5013
5014
5015
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5010

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @owner = args[:owner] if args.key?(:owner)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end