Class: Google::Apis::DatamigrationV1::SeedConversionWorkspaceRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SeedConversionWorkspaceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Request message for 'SeedConversionWorkspace' request.
Instance Attribute Summary collapse
-
#auto_commit ⇒ Boolean
(also: #auto_commit?)
Should the conversion workspace be committed automatically after the seed operation.
-
#destination_connection_profile ⇒ String
Optional.
-
#source_connection_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SeedConversionWorkspaceRequest
constructor
A new instance of SeedConversionWorkspaceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SeedConversionWorkspaceRequest
Returns a new instance of SeedConversionWorkspaceRequest.
5277 5278 5279 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_commit ⇒ Boolean Also known as: auto_commit?
Should the conversion workspace be committed automatically after the seed
operation.
Corresponds to the JSON property autoCommit
5264 5265 5266 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5264 def auto_commit @auto_commit end |
#destination_connection_profile ⇒ String
Optional. Fully qualified (Uri) name of the destination connection profile.
Corresponds to the JSON property destinationConnectionProfile
5270 5271 5272 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5270 def destination_connection_profile @destination_connection_profile end |
#source_connection_profile ⇒ String
Optional. Fully qualified (Uri) name of the source connection profile.
Corresponds to the JSON property sourceConnectionProfile
5275 5276 5277 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5275 def source_connection_profile @source_connection_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5282 5283 5284 5285 5286 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5282 def update!(**args) @auto_commit = args[:auto_commit] if args.key?(:auto_commit) @destination_connection_profile = args[:destination_connection_profile] if args.key?(:destination_connection_profile) @source_connection_profile = args[:source_connection_profile] if args.key?(:source_connection_profile) end |