Class: Google::Apis::DatamigrationV1::SequenceEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Sequence's parent is a schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SequenceEntity

Returns a new instance of SequenceEntity.



5354
5355
5356
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cacheFixnum

Indicates number of entries to cache / precreate. Corresponds to the JSON property cache

Returns:

  • (Fixnum)


5315
5316
5317
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5315

def cache
  @cache
end

#custom_featuresHash<String,Object>

Custom engine specific features. Corresponds to the JSON property customFeatures

Returns:

  • (Hash<String,Object>)


5320
5321
5322
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5320

def custom_features
  @custom_features
end

#cycleBoolean Also known as: cycle?

Indicates whether the sequence value should cycle through. Corresponds to the JSON property cycle

Returns:

  • (Boolean)


5325
5326
5327
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5325

def cycle
  @cycle
end

#incrementFixnum

Increment value for the sequence. Corresponds to the JSON property increment

Returns:

  • (Fixnum)


5331
5332
5333
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5331

def increment
  @increment
end

#max_valueString

Maximum number for the sequence represented as bytes to accommodate large. numbers Corresponds to the JSON property maxValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5338
5339
5340
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5338

def max_value
  @max_value
end

#min_valueString

Minimum number for the sequence represented as bytes to accommodate large. numbers Corresponds to the JSON property minValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5345
5346
5347
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5345

def min_value
  @min_value
end

#start_valueString

Start number for the sequence represented as bytes to accommodate large. numbers Corresponds to the JSON property startValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5352
5353
5354
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5352

def start_value
  @start_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5359
5360
5361
5362
5363
5364
5365
5366
5367
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5359

def update!(**args)
  @cache = args[:cache] if args.key?(:cache)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @cycle = args[:cycle] if args.key?(:cycle)
  @increment = args[:increment] if args.key?(:increment)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @start_value = args[:start_value] if args.key?(:start_value)
end