Class: Google::Apis::DatamigrationV1::SingleColumnChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Options to configure rule type SingleColumnChange. The rule is used to change the properties of a column. The rule filter field can refer to one entity. The rule scope can be one of: Column. When using this rule, if a field is not specified than the destination column's configuration will be the same as the one in the source column..

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleColumnChange

Returns a new instance of SingleColumnChange.



5572
5573
5574
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arrayBoolean Also known as: array?

Optional. Is the column of array type. Corresponds to the JSON property array

Returns:

  • (Boolean)


5494
5495
5496
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5494

def array
  @array
end

#array_lengthFixnum

Optional. The length of the array, only relevant if the column type is an array. Corresponds to the JSON property arrayLength

Returns:

  • (Fixnum)


5501
5502
5503
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5501

def array_length
  @array_length
end

#auto_generatedBoolean Also known as: auto_generated?

Optional. Is the column auto-generated/identity. Corresponds to the JSON property autoGenerated

Returns:

  • (Boolean)


5506
5507
5508
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5506

def auto_generated
  @auto_generated
end

#charsetString

Optional. Charset override - instead of table level charset. Corresponds to the JSON property charset

Returns:

  • (String)


5512
5513
5514
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5512

def charset
  @charset
end

#collationString

Optional. Collation override - instead of table level collation. Corresponds to the JSON property collation

Returns:

  • (String)


5517
5518
5519
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5517

def collation
  @collation
end

#commentString

Optional. Comment associated with the column. Corresponds to the JSON property comment

Returns:

  • (String)


5522
5523
5524
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5522

def comment
  @comment
end

#custom_featuresHash<String,Object>

Optional. Custom engine specific features. Corresponds to the JSON property customFeatures

Returns:

  • (Hash<String,Object>)


5527
5528
5529
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5527

def custom_features
  @custom_features
end

#data_typeString

Optional. Column data type name. Corresponds to the JSON property dataType

Returns:

  • (String)


5532
5533
5534
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5532

def data_type
  @data_type
end

#fractional_seconds_precisionFixnum

Optional. Column fractional seconds precision - e.g. 2 as in timestamp (2) - when relevant. Corresponds to the JSON property fractionalSecondsPrecision

Returns:

  • (Fixnum)


5538
5539
5540
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5538

def fractional_seconds_precision
  @fractional_seconds_precision
end

#lengthFixnum

Optional. Column length - e.g. 50 as in varchar (50) - when relevant. Corresponds to the JSON property length

Returns:

  • (Fixnum)


5543
5544
5545
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5543

def length
  @length
end

#nullableBoolean Also known as: nullable?

Optional. Is the column nullable. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


5548
5549
5550
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5548

def nullable
  @nullable
end

#precisionFixnum

Optional. Column precision - e.g. 8 as in double (8,2) - when relevant. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


5554
5555
5556
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5554

def precision
  @precision
end

#scaleFixnum

Optional. Column scale - e.g. 2 as in double (8,2) - when relevant. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


5559
5560
5561
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5559

def scale
  @scale
end

#set_valuesArray<String>

Optional. Specifies the list of values allowed in the column. Corresponds to the JSON property setValues

Returns:

  • (Array<String>)


5564
5565
5566
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5564

def set_values
  @set_values
end

#udtBoolean Also known as: udt?

Optional. Is the column a UDT (User-defined Type). Corresponds to the JSON property udt

Returns:

  • (Boolean)


5569
5570
5571
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5569

def udt
  @udt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5577

def update!(**args)
  @array = args[:array] if args.key?(:array)
  @array_length = args[:array_length] if args.key?(:array_length)
  @auto_generated = args[:auto_generated] if args.key?(:auto_generated)
  @charset = args[:charset] if args.key?(:charset)
  @collation = args[:collation] if args.key?(:collation)
  @comment = args[:comment] if args.key?(:comment)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @data_type = args[:data_type] if args.key?(:data_type)
  @fractional_seconds_precision = args[:fractional_seconds_precision] if args.key?(:fractional_seconds_precision)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @precision = args[:precision] if args.key?(:precision)
  @scale = args[:scale] if args.key?(:scale)
  @set_values = args[:set_values] if args.key?(:set_values)
  @udt = args[:udt] if args.key?(:udt)
end