Class: Google::Apis::DatamigrationV1::SourceNumericFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Filter for fixed point number data types such as NUMERIC/NUMBER

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceNumericFilter

Returns a new instance of SourceNumericFilter.



5646
5647
5648
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#numeric_filter_optionString

Required. Enum to set the option defining the datatypes numeric filter has to be applied to Corresponds to the JSON property numericFilterOption

Returns:

  • (String)


5620
5621
5622
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5620

def numeric_filter_option
  @numeric_filter_option
end

#source_max_precision_filterFixnum

Optional. The filter will match columns with precision smaller than or equal to this number. Corresponds to the JSON property sourceMaxPrecisionFilter

Returns:

  • (Fixnum)


5626
5627
5628
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5626

def source_max_precision_filter
  @source_max_precision_filter
end

#source_max_scale_filterFixnum

Optional. The filter will match columns with scale smaller than or equal to this number. Corresponds to the JSON property sourceMaxScaleFilter

Returns:

  • (Fixnum)


5632
5633
5634
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5632

def source_max_scale_filter
  @source_max_scale_filter
end

#source_min_precision_filterFixnum

Optional. The filter will match columns with precision greater than or equal to this number. Corresponds to the JSON property sourceMinPrecisionFilter

Returns:

  • (Fixnum)


5638
5639
5640
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5638

def source_min_precision_filter
  @source_min_precision_filter
end

#source_min_scale_filterFixnum

Optional. The filter will match columns with scale greater than or equal to this number. Corresponds to the JSON property sourceMinScaleFilter

Returns:

  • (Fixnum)


5644
5645
5646
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5644

def source_min_scale_filter
  @source_min_scale_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5651
5652
5653
5654
5655
5656
5657
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5651

def update!(**args)
  @numeric_filter_option = args[:numeric_filter_option] if args.key?(:numeric_filter_option)
  @source_max_precision_filter = args[:source_max_precision_filter] if args.key?(:source_max_precision_filter)
  @source_max_scale_filter = args[:source_max_scale_filter] if args.key?(:source_max_scale_filter)
  @source_min_precision_filter = args[:source_min_precision_filter] if args.key?(:source_min_precision_filter)
  @source_min_scale_filter = args[:source_min_scale_filter] if args.key?(:source_min_scale_filter)
end