Class: Google::Apis::DatamigrationV1::SqlAclEntry
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SqlAclEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
An entry for an Access Control list.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
The time when this access control entry expires in RFC 3339 format, for example:
2012-11-15T16:19:00.094Z. -
#label ⇒ String
A label to identify this entry.
-
#ttl ⇒ String
Input only.
-
#value ⇒ String
The allowlisted value for the access control list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlAclEntry
constructor
A new instance of SqlAclEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlAclEntry
Returns a new instance of SqlAclEntry.
5909 5910 5911 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
The time when this access control entry expires in RFC 3339 format, for example: 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property expireTime
5892 5893 5894 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5892 def expire_time @expire_time end |
#label ⇒ String
A label to identify this entry.
Corresponds to the JSON property label
5897 5898 5899 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5897 def label @label end |
#ttl ⇒ String
Input only. The time-to-leave of this access control entry.
Corresponds to the JSON property ttl
5902 5903 5904 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5902 def ttl @ttl end |
#value ⇒ String
The allowlisted value for the access control list.
Corresponds to the JSON property value
5907 5908 5909 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5907 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5914 5915 5916 5917 5918 5919 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5914 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @label = args[:label] if args.key?(:label) @ttl = args[:ttl] if args.key?(:ttl) @value = args[:value] if args.key?(:value) end |