Class: Google::Apis::DatamigrationV1::SqlServerBackups

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies the backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerBackups

Returns a new instance of SqlServerBackups.



5934
5935
5936
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_bucketString

Required. The Cloud Storage bucket that stores backups for all replicated databases. Corresponds to the JSON property gcsBucket

Returns:

  • (String)


5927
5928
5929
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5927

def gcs_bucket
  @gcs_bucket
end

#gcs_prefixString

Optional. Cloud Storage path inside the bucket that stores backups. Corresponds to the JSON property gcsPrefix

Returns:

  • (String)


5932
5933
5934
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5932

def gcs_prefix
  @gcs_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5939
5940
5941
5942
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5939

def update!(**args)
  @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
end