Class: Google::Apis::DatamigrationV1::SqlServerDatabaseBackup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies the backup details for a single database in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerDatabaseBackup

Returns a new instance of SqlServerDatabaseBackup.



6063
6064
6065
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

Required. Name of a SQL Server database for which to define backup configuration. Corresponds to the JSON property database

Returns:

  • (String)


6056
6057
6058
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6056

def database
  @database
end

#encryption_optionsGoogle::Apis::DatamigrationV1::SqlServerEncryptionOptions

Encryption settings for the SQL Server database. Corresponds to the JSON property encryptionOptions



6061
6062
6063
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6061

def encryption_options
  @encryption_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6068
6069
6070
6071
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6068

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @encryption_options = args[:encryption_options] if args.key?(:encryption_options)
end