Class: Google::Apis::DatamigrationV1::SynonymEntity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SynonymEntity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Synonym's parent is a schema.
Instance Attribute Summary collapse
-
#custom_features ⇒ Hash<String,Object>
Custom engine specific features.
-
#source_entity ⇒ String
The name of the entity for which the synonym is being created (the source).
-
#source_type ⇒ String
The type of the entity for which the synonym is being created (usually a table or a sequence).
Instance Method Summary collapse
-
#initialize(**args) ⇒ SynonymEntity
constructor
A new instance of SynonymEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SynonymEntity
Returns a new instance of SynonymEntity.
6574 6575 6576 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_features ⇒ Hash<String,Object>
Custom engine specific features.
Corresponds to the JSON property customFeatures
6561 6562 6563 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6561 def custom_features @custom_features end |
#source_entity ⇒ String
The name of the entity for which the synonym is being created (the source).
Corresponds to the JSON property sourceEntity
6566 6567 6568 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6566 def source_entity @source_entity end |
#source_type ⇒ String
The type of the entity for which the synonym is being created (usually a table
or a sequence).
Corresponds to the JSON property sourceType
6572 6573 6574 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6572 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6579 6580 6581 6582 6583 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6579 def update!(**args) @custom_features = args[:custom_features] if args.key?(:custom_features) @source_entity = args[:source_entity] if args.key?(:source_entity) @source_type = args[:source_type] if args.key?(:source_type) end |