Class: Google::Apis::DatamigrationV1::TriggerEntity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::TriggerEntity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Trigger is not used as an independent entity, it is retrieved as part of a Table entity.
Instance Attribute Summary collapse
-
#custom_features ⇒ Hash<String,Object>
Custom engine specific features.
-
#name ⇒ String
The name of the trigger.
-
#sql_code ⇒ String
The SQL code which creates the trigger.
-
#trigger_type ⇒ String
Indicates when the trigger fires, for example BEFORE STATEMENT, AFTER EACH ROW.
-
#triggering_events ⇒ Array<String>
The DML, DDL, or database events that fire the trigger, for example INSERT, UPDATE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TriggerEntity
constructor
A new instance of TriggerEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TriggerEntity
Returns a new instance of TriggerEntity.
6725 6726 6727 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_features ⇒ Hash<String,Object>
Custom engine specific features.
Corresponds to the JSON property customFeatures
6702 6703 6704 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6702 def custom_features @custom_features end |
#name ⇒ String
The name of the trigger.
Corresponds to the JSON property name
6707 6708 6709 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6707 def name @name end |
#sql_code ⇒ String
The SQL code which creates the trigger.
Corresponds to the JSON property sqlCode
6712 6713 6714 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6712 def sql_code @sql_code end |
#trigger_type ⇒ String
Indicates when the trigger fires, for example BEFORE STATEMENT, AFTER EACH ROW.
Corresponds to the JSON property triggerType
6717 6718 6719 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6717 def trigger_type @trigger_type end |
#triggering_events ⇒ Array<String>
The DML, DDL, or database events that fire the trigger, for example INSERT,
UPDATE.
Corresponds to the JSON property triggeringEvents
6723 6724 6725 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6723 def triggering_events @triggering_events end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6730 6731 6732 6733 6734 6735 6736 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6730 def update!(**args) @custom_features = args[:custom_features] if args.key?(:custom_features) @name = args[:name] if args.key?(:name) @sql_code = args[:sql_code] if args.key?(:sql_code) @trigger_type = args[:trigger_type] if args.key?(:trigger_type) @triggering_events = args[:triggering_events] if args.key?(:triggering_events) end |