Class: Google::Apis::DatamigrationV1::ValueTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Description of data transformation during migration as part of the ConditionalColumnSetValue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValueTransformation

Returns a new instance of ValueTransformation.



6907
6908
6909
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apply_hashGoogle::Apis::DatamigrationV1::ApplyHash

Apply a hash function on the value. Corresponds to the JSON property applyHash



6844
6845
6846
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6844

def apply_hash
  @apply_hash
end

#assign_max_valueGoogle::Apis::DatamigrationV1::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property assignMaxValue



6852
6853
6854
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6852

def assign_max_value
  @assign_max_value
end

#assign_min_valueGoogle::Apis::DatamigrationV1::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property assignMinValue



6860
6861
6862
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6860

def assign_min_value
  @assign_min_value
end

#assign_nullGoogle::Apis::DatamigrationV1::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property assignNull



6868
6869
6870
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6868

def assign_null
  @assign_null
end

#assign_specific_valueGoogle::Apis::DatamigrationV1::AssignSpecificValue

Set to a specific value (value is converted to fit the target data type) Corresponds to the JSON property assignSpecificValue



6873
6874
6875
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6873

def assign_specific_value
  @assign_specific_value
end

#double_comparisonGoogle::Apis::DatamigrationV1::DoubleComparisonFilter

Filter based on relation between source value and compare value of type double in ConditionalColumnSetValue Corresponds to the JSON property doubleComparison



6879
6880
6881
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6879

def double_comparison
  @double_comparison
end

#int_comparisonGoogle::Apis::DatamigrationV1::IntComparisonFilter

Filter based on relation between source value and compare value of type integer in ConditionalColumnSetValue Corresponds to the JSON property intComparison



6885
6886
6887
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6885

def int_comparison
  @int_comparison
end

#is_nullGoogle::Apis::DatamigrationV1::Empty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property isNull



6893
6894
6895
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6893

def is_null
  @is_null
end

#round_scaleGoogle::Apis::DatamigrationV1::RoundToScale

This allows the data to change scale, for example if the source is 2 digits after the decimal point, specify round to scale value = 2. If for example the value needs to be converted to an integer, use round to scale value = 0. Corresponds to the JSON property roundScale



6900
6901
6902
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6900

def round_scale
  @round_scale
end

#value_listGoogle::Apis::DatamigrationV1::ValueListFilter

A list of values to filter by in ConditionalColumnSetValue Corresponds to the JSON property valueList



6905
6906
6907
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6905

def value_list
  @value_list
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6912

def update!(**args)
  @apply_hash = args[:apply_hash] if args.key?(:apply_hash)
  @assign_max_value = args[:assign_max_value] if args.key?(:assign_max_value)
  @assign_min_value = args[:assign_min_value] if args.key?(:assign_min_value)
  @assign_null = args[:assign_null] if args.key?(:assign_null)
  @assign_specific_value = args[:assign_specific_value] if args.key?(:assign_specific_value)
  @double_comparison = args[:double_comparison] if args.key?(:double_comparison)
  @int_comparison = args[:int_comparison] if args.key?(:int_comparison)
  @is_null = args[:is_null] if args.key?(:is_null)
  @round_scale = args[:round_scale] if args.key?(:round_scale)
  @value_list = args[:value_list] if args.key?(:value_list)
end