Class: Google::Apis::DatamigrationV1::VmCreationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::VmCreationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
VM creation configuration message
Instance Attribute Summary collapse
-
#subnet ⇒ String
The subnet name the vm needs to be created in.
-
#vm_machine_type ⇒ String
Required.
-
#vm_zone ⇒ String
The Google Cloud Platform zone to create the VM in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmCreationConfig
constructor
A new instance of VmCreationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmCreationConfig
Returns a new instance of VmCreationConfig.
6943 6944 6945 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#subnet ⇒ String
The subnet name the vm needs to be created in.
Corresponds to the JSON property subnet
6931 6932 6933 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6931 def subnet @subnet end |
#vm_machine_type ⇒ String
Required. VM instance machine type to create.
Corresponds to the JSON property vmMachineType
6936 6937 6938 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6936 def vm_machine_type @vm_machine_type end |
#vm_zone ⇒ String
The Google Cloud Platform zone to create the VM in.
Corresponds to the JSON property vmZone
6941 6942 6943 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6941 def vm_zone @vm_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6948 6949 6950 6951 6952 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6948 def update!(**args) @subnet = args[:subnet] if args.key?(:subnet) @vm_machine_type = args[:vm_machine_type] if args.key?(:vm_machine_type) @vm_zone = args[:vm_zone] if args.key?(:vm_zone) end |