Class: Google::Apis::DatamigrationV1::CloudSqlSettings
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::CloudSqlSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Settings for creating a Cloud SQL database instance.
Instance Attribute Summary collapse
-
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is applicable only when the instance state is 'RUNNABLE'.
-
#auto_storage_increase ⇒ Boolean
(also: #auto_storage_increase?)
[default: ON] If you enable this setting, Cloud SQL checks your available storage every 30 seconds.
-
#availability_type ⇒ String
Optional.
-
#cmek_key_name ⇒ String
The KMS key name used for the csql instance.
-
#collation ⇒ String
The Cloud SQL default instance level collation.
-
#data_cache_config ⇒ Google::Apis::DatamigrationV1::DataCacheConfig
Data cache is an optional feature available for Cloud SQL for MySQL Enterprise Plus edition only.
-
#data_disk_provisioned_iops ⇒ Fixnum
Optional.
-
#data_disk_provisioned_throughput ⇒ Fixnum
Optional.
-
#data_disk_size_gb ⇒ Fixnum
The storage capacity available to the database, in GB.
-
#data_disk_type ⇒ String
The type of storage:
PD_SSD(default) orPD_HDDorHYPERDISK_BALANCED. -
#database_flags ⇒ Hash<String,String>
The database flags passed to the Cloud SQL instance at startup.
-
#database_version ⇒ String
The database engine type and version.
-
#database_version_name ⇒ String
Optional.
-
#edition ⇒ String
Optional.
-
#ip_config ⇒ Google::Apis::DatamigrationV1::SqlIpConfig
IP Management configuration.
-
#root_password ⇒ String
Input only.
-
#root_password_set ⇒ Boolean
(also: #root_password_set?)
Output only.
-
#secondary_zone ⇒ String
Optional.
-
#source_id ⇒ String
The Database Migration Service source connection profile ID, in the format:
projects/my_project_name/locations/us-central1/connectionProfiles/ connection_profile_IDCorresponds to the JSON propertysourceId. -
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased.
-
#tier ⇒ String
The tier (or machine type) for this instance, for example:
db-n1-standard-1( MySQL instances) ordb-custom-1-3840(PostgreSQL instances). -
#user_labels ⇒ Hash<String,String>
The resource labels for a Cloud SQL instance to use to annotate any related underlying resources such as Compute Engine VMs.
-
#zone ⇒ String
The Google Cloud Platform zone where your Cloud SQL database instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudSqlSettings
constructor
A new instance of CloudSqlSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudSqlSettings
Returns a new instance of CloudSqlSettings.
730 731 732 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is
applicable only when the instance state is 'RUNNABLE'. Valid values: 'ALWAYS':
The instance is on, and remains so even in the absence of connection requests.
NEVER: The instance is off; it is not activated, even if a connection
request arrives.
Corresponds to the JSON property activationPolicy
588 589 590 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 588 def activation_policy @activation_policy end |
#auto_storage_increase ⇒ Boolean Also known as: auto_storage_increase?
[default: ON] If you enable this setting, Cloud SQL checks your available
storage every 30 seconds. If the available storage falls below a threshold
size, Cloud SQL automatically adds additional storage capacity. If the
available storage repeatedly falls below the threshold size, Cloud SQL
continues to add storage until it reaches the maximum of 30 TB.
Corresponds to the JSON property autoStorageIncrease
597 598 599 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 597 def auto_storage_increase @auto_storage_increase end |
#availability_type ⇒ String
Optional. Availability type. Potential values: * ZONAL: The instance serves
data from only one zone. Outages in that zone affect data availability. *
REGIONAL: The instance can serve data from more than one zone in a region (it
is highly available).
Corresponds to the JSON property availabilityType
606 607 608 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 606 def availability_type @availability_type end |
#cmek_key_name ⇒ String
The KMS key name used for the csql instance.
Corresponds to the JSON property cmekKeyName
611 612 613 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 611 def cmek_key_name @cmek_key_name end |
#collation ⇒ String
The Cloud SQL default instance level collation.
Corresponds to the JSON property collation
616 617 618 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 616 def collation @collation end |
#data_cache_config ⇒ Google::Apis::DatamigrationV1::DataCacheConfig
Data cache is an optional feature available for Cloud SQL for MySQL Enterprise
Plus edition only. For more information on data cache, see Data cache
overview in Cloud SQL
documentation.
Corresponds to the JSON property dataCacheConfig
624 625 626 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 624 def data_cache_config @data_cache_config end |
#data_disk_provisioned_iops ⇒ Fixnum
Optional. Provisioned number of I/O operations per second for the data disk.
This field is only used for hyperdisk-balanced disk types.
Corresponds to the JSON property dataDiskProvisionedIops
630 631 632 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 630 def data_disk_provisioned_iops @data_disk_provisioned_iops end |
#data_disk_provisioned_throughput ⇒ Fixnum
Optional. Provisioned throughput measured in MiB per second for the data disk.
This field is only used for hyperdisk-balanced disk types.
Corresponds to the JSON property dataDiskProvisionedThroughput
636 637 638 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 636 def data_disk_provisioned_throughput @data_disk_provisioned_throughput end |
#data_disk_size_gb ⇒ Fixnum
The storage capacity available to the database, in GB. The minimum (and
default) size is 10GB.
Corresponds to the JSON property dataDiskSizeGb
642 643 644 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 642 def data_disk_size_gb @data_disk_size_gb end |
#data_disk_type ⇒ String
The type of storage: PD_SSD (default) or PD_HDD or HYPERDISK_BALANCED.
Corresponds to the JSON property dataDiskType
647 648 649 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 647 def data_disk_type @data_disk_type end |
#database_flags ⇒ Hash<String,String>
The database flags passed to the Cloud SQL instance at startup. An object
containing a list of "key": value pairs. Example: "name": "wrench", "mass": "
1.3kg", "count": "3".
Corresponds to the JSON property databaseFlags
654 655 656 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 654 def database_flags @database_flags end |
#database_version ⇒ String
The database engine type and version. Deprecated. Use database_version_name
instead.
Corresponds to the JSON property databaseVersion
660 661 662 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 660 def database_version @database_version end |
#database_version_name ⇒ String
Optional. The database engine type and version name.
Corresponds to the JSON property databaseVersionName
665 666 667 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 665 def database_version_name @database_version_name end |
#edition ⇒ String
Optional. The edition of the given Cloud SQL instance.
Corresponds to the JSON property edition
670 671 672 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 670 def edition @edition end |
#ip_config ⇒ Google::Apis::DatamigrationV1::SqlIpConfig
IP Management configuration.
Corresponds to the JSON property ipConfig
675 676 677 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 675 def ip_config @ip_config end |
#root_password ⇒ String
Input only. Initial root password.
Corresponds to the JSON property rootPassword
680 681 682 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 680 def root_password @root_password end |
#root_password_set ⇒ Boolean Also known as: root_password_set?
Output only. Indicates If this connection profile root password is stored.
Corresponds to the JSON property rootPasswordSet
685 686 687 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 685 def root_password_set @root_password_set end |
#secondary_zone ⇒ String
Optional. The Google Cloud Platform zone where the failover Cloud SQL database
instance is located. Used when the Cloud SQL database availability type is
REGIONAL (i.e. multiple zones / highly available).
Corresponds to the JSON property secondaryZone
693 694 695 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 693 def secondary_zone @secondary_zone end |
#source_id ⇒ String
The Database Migration Service source connection profile ID, in the format:
projects/my_project_name/locations/us-central1/connectionProfiles/
connection_profile_ID
Corresponds to the JSON property sourceId
700 701 702 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 700 def source_id @source_id end |
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased. The
default value is 0, which specifies that there is no limit.
Corresponds to the JSON property storageAutoResizeLimit
706 707 708 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 706 def storage_auto_resize_limit @storage_auto_resize_limit end |
#tier ⇒ String
The tier (or machine type) for this instance, for example: db-n1-standard-1 (
MySQL instances) or db-custom-1-3840 (PostgreSQL instances). For more
information, see Cloud SQL Instance Settings.
Corresponds to the JSON property tier
714 715 716 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 714 def tier @tier end |
#user_labels ⇒ Hash<String,String>
The resource labels for a Cloud SQL instance to use to annotate any related
underlying resources such as Compute Engine VMs. An object containing a list
of "key": "value" pairs. Example: "name": "wrench", "mass": "18kg", "count":
"3".
Corresponds to the JSON property userLabels
722 723 724 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 722 def user_labels @user_labels end |
#zone ⇒ String
The Google Cloud Platform zone where your Cloud SQL database instance is
located.
Corresponds to the JSON property zone
728 729 730 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 728 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 735 def update!(**args) @activation_policy = args[:activation_policy] if args.key?(:activation_policy) @auto_storage_increase = args[:auto_storage_increase] if args.key?(:auto_storage_increase) @availability_type = args[:availability_type] if args.key?(:availability_type) @cmek_key_name = args[:cmek_key_name] if args.key?(:cmek_key_name) @collation = args[:collation] if args.key?(:collation) @data_cache_config = args[:data_cache_config] if args.key?(:data_cache_config) @data_disk_provisioned_iops = args[:data_disk_provisioned_iops] if args.key?(:data_disk_provisioned_iops) @data_disk_provisioned_throughput = args[:data_disk_provisioned_throughput] if args.key?(:data_disk_provisioned_throughput) @data_disk_size_gb = args[:data_disk_size_gb] if args.key?(:data_disk_size_gb) @data_disk_type = args[:data_disk_type] if args.key?(:data_disk_type) @database_flags = args[:database_flags] if args.key?(:database_flags) @database_version = args[:database_version] if args.key?(:database_version) @database_version_name = args[:database_version_name] if args.key?(:database_version_name) @edition = args[:edition] if args.key?(:edition) @ip_config = args[:ip_config] if args.key?(:ip_config) @root_password = args[:root_password] if args.key?(:root_password) @root_password_set = args[:root_password_set] if args.key?(:root_password_set) @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone) @source_id = args[:source_id] if args.key?(:source_id) @storage_auto_resize_limit = args[:storage_auto_resize_limit] if args.key?(:storage_auto_resize_limit) @tier = args[:tier] if args.key?(:tier) @user_labels = args[:user_labels] if args.key?(:user_labels) @zone = args[:zone] if args.key?(:zone) end |