Class: Google::Apis::DatamigrationV1::ConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::ConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
A connection profile definition.
Instance Attribute Summary collapse
-
#alloydb ⇒ Google::Apis::DatamigrationV1::AlloyDbConnectionProfile
Specifies required connection parameters, and the parameters required to create an AlloyDB destination cluster.
-
#cloudsql ⇒ Google::Apis::DatamigrationV1::CloudSqlConnectionProfile
Specifies required connection parameters, and, optionally, the parameters required to create a Cloud SQL destination database instance.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The connection profile display name.
-
#error ⇒ Google::Apis::DatamigrationV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The resource labels for connection profile to use to annotate any related underlying resources such as Compute Engine VMs.
-
#mysql ⇒ Google::Apis::DatamigrationV1::MySqlConnectionProfile
Specifies connection parameters required specifically for MySQL databases.
-
#name ⇒ String
The name of this connection profile resource in the form of projects/
project/ locations/location/connectionProfiles/connectionProfile. -
#oracle ⇒ Google::Apis::DatamigrationV1::OracleConnectionProfile
Specifies connection parameters required specifically for Oracle databases.
-
#postgresql ⇒ Google::Apis::DatamigrationV1::PostgreSqlConnectionProfile
Specifies connection parameters required specifically for PostgreSQL databases.
-
#provider ⇒ String
The database provider.
-
#role ⇒ String
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#sqlserver ⇒ Google::Apis::DatamigrationV1::SqlServerConnectionProfile
Specifies connection parameters required specifically for SQL Server databases.
-
#state ⇒ String
The current connection profile state (e.g. DRAFT, READY, or FAILED).
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectionProfile
constructor
A new instance of ConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectionProfile
Returns a new instance of ConnectionProfile.
1061 1062 1063 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alloydb ⇒ Google::Apis::DatamigrationV1::AlloyDbConnectionProfile
Specifies required connection parameters, and the parameters required to
create an AlloyDB destination cluster.
Corresponds to the JSON property alloydb
963 964 965 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 963 def alloydb @alloydb end |
#cloudsql ⇒ Google::Apis::DatamigrationV1::CloudSqlConnectionProfile
Specifies required connection parameters, and, optionally, the parameters
required to create a Cloud SQL destination database instance.
Corresponds to the JSON property cloudsql
969 970 971 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 969 def cloudsql @cloudsql end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. A timestamp in
RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:
23.045123456Z".
Corresponds to the JSON property createTime
976 977 978 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 976 def create_time @create_time end |
#display_name ⇒ String
The connection profile display name.
Corresponds to the JSON property displayName
981 982 983 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 981 def display_name @display_name end |
#error ⇒ Google::Apis::DatamigrationV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
991 992 993 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 991 def error @error end |
#labels ⇒ Hash<String,String>
The resource labels for connection profile to use to annotate any related
underlying resources such as Compute Engine VMs. An object containing a list
of "key": "value" pairs. Example: "name": "wrench", "mass": "1.3kg", "count"
: "3".
Corresponds to the JSON property labels
999 1000 1001 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 999 def labels @labels end |
#mysql ⇒ Google::Apis::DatamigrationV1::MySqlConnectionProfile
Specifies connection parameters required specifically for MySQL databases.
Corresponds to the JSON property mysql
1004 1005 1006 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1004 def mysql @mysql end |
#name ⇒ String
The name of this connection profile resource in the form of projects/project/
locations/location/connectionProfiles/connectionProfile.
Corresponds to the JSON property name
1010 1011 1012 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1010 def name @name end |
#oracle ⇒ Google::Apis::DatamigrationV1::OracleConnectionProfile
Specifies connection parameters required specifically for Oracle databases.
Corresponds to the JSON property oracle
1015 1016 1017 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1015 def oracle @oracle end |
#postgresql ⇒ Google::Apis::DatamigrationV1::PostgreSqlConnectionProfile
Specifies connection parameters required specifically for PostgreSQL databases.
Corresponds to the JSON property postgresql
1020 1021 1022 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1020 def postgresql @postgresql end |
#provider ⇒ String
The database provider.
Corresponds to the JSON property provider
1025 1026 1027 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1025 def provider @provider end |
#role ⇒ String
Optional. The connection profile role.
Corresponds to the JSON property role
1030 1031 1032 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1030 def role @role end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1035 1036 1037 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1035 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1041 1042 1043 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1041 def satisfies_pzs @satisfies_pzs end |
#sqlserver ⇒ Google::Apis::DatamigrationV1::SqlServerConnectionProfile
Specifies connection parameters required specifically for SQL Server databases.
Corresponds to the JSON property sqlserver
1047 1048 1049 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1047 def sqlserver @sqlserver end |
#state ⇒ String
The current connection profile state (e.g. DRAFT, READY, or FAILED).
Corresponds to the JSON property state
1052 1053 1054 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1052 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. A timestamp in
RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01:
23.045123456Z".
Corresponds to the JSON property updateTime
1059 1060 1061 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1059 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1066 def update!(**args) @alloydb = args[:alloydb] if args.key?(:alloydb) @cloudsql = args[:cloudsql] if args.key?(:cloudsql) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @mysql = args[:mysql] if args.key?(:mysql) @name = args[:name] if args.key?(:name) @oracle = args[:oracle] if args.key?(:oracle) @postgresql = args[:postgresql] if args.key?(:postgresql) @provider = args[:provider] if args.key?(:provider) @role = args[:role] if args.key?(:role) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @sqlserver = args[:sqlserver] if args.key?(:sqlserver) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |