Class: Google::Apis::DatamigrationV1::ConversionWorkspace
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::ConversionWorkspace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
The main conversion workspace resource entity.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#destination ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
-
#destination_provider ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#global_settings ⇒ Hash<String,String>
Optional.
-
#has_uncommitted_changes ⇒ Boolean
(also: #has_uncommitted_changes?)
Output only.
-
#latest_commit_id ⇒ String
Output only.
-
#latest_commit_time ⇒ String
Output only.
-
#name ⇒ String
Full name of the workspace resource, in the form of: projects/
project/ locations/location/conversionWorkspaces/conversion_workspace. -
#source ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
-
#source_provider ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversionWorkspace
constructor
A new instance of ConversionWorkspace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversionWorkspace
Returns a new instance of ConversionWorkspace.
1243 1244 1245 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the workspace resource was created.
Corresponds to the JSON property createTime
1179 1180 1181 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1179 def create_time @create_time end |
#destination ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
Corresponds to the JSON property destination
1184 1185 1186 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1184 def destination @destination end |
#destination_provider ⇒ String
Optional. The provider for the destination database.
Corresponds to the JSON property destinationProvider
1189 1190 1191 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1189 def destination_provider @destination_provider end |
#display_name ⇒ String
Optional. The display name for the workspace.
Corresponds to the JSON property displayName
1194 1195 1196 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1194 def display_name @display_name end |
#global_settings ⇒ Hash<String,String>
Optional. A generic list of settings for the workspace. The settings are
database pair dependant and can indicate default behavior for the mapping
rules engine or turn on or off specific features. Such examples can be:
convert_foreign_key_to_interleave=true, skip_triggers=false,
ignore_non_table_synonyms=true
Corresponds to the JSON property globalSettings
1203 1204 1205 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1203 def global_settings @global_settings end |
#has_uncommitted_changes ⇒ Boolean Also known as: has_uncommitted_changes?
Output only. Whether the workspace has uncommitted changes (changes which were
made after the workspace was committed).
Corresponds to the JSON property hasUncommittedChanges
1209 1210 1211 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1209 def has_uncommitted_changes @has_uncommitted_changes end |
#latest_commit_id ⇒ String
Output only. The latest commit ID.
Corresponds to the JSON property latestCommitId
1215 1216 1217 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1215 def latest_commit_id @latest_commit_id end |
#latest_commit_time ⇒ String
Output only. The timestamp when the workspace was committed.
Corresponds to the JSON property latestCommitTime
1220 1221 1222 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1220 def latest_commit_time @latest_commit_time end |
#name ⇒ String
Full name of the workspace resource, in the form of: projects/project/
locations/location/conversionWorkspaces/conversion_workspace.
Corresponds to the JSON property name
1226 1227 1228 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1226 def name @name end |
#source ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
Corresponds to the JSON property source
1231 1232 1233 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1231 def source @source end |
#source_provider ⇒ String
Optional. The provider for the source database.
Corresponds to the JSON property sourceProvider
1236 1237 1238 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1236 def source_provider @source_provider end |
#update_time ⇒ String
Output only. The timestamp when the workspace resource was last updated.
Corresponds to the JSON property updateTime
1241 1242 1243 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1241 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1248 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @destination = args[:destination] if args.key?(:destination) @destination_provider = args[:destination_provider] if args.key?(:destination_provider) @display_name = args[:display_name] if args.key?(:display_name) @global_settings = args[:global_settings] if args.key?(:global_settings) @has_uncommitted_changes = args[:has_uncommitted_changes] if args.key?(:has_uncommitted_changes) @latest_commit_id = args[:latest_commit_id] if args.key?(:latest_commit_id) @latest_commit_time = args[:latest_commit_time] if args.key?(:latest_commit_time) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @source_provider = args[:source_provider] if args.key?(:source_provider) @update_time = args[:update_time] if args.key?(:update_time) end |