Class: Google::Apis::DatamigrationV1::ConversionWorkspace
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::ConversionWorkspace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
The main conversion workspace resource entity.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#destination ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
-
#destination_provider ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#global_settings ⇒ Hash<String,String>
Optional.
-
#has_uncommitted_changes ⇒ Boolean
(also: #has_uncommitted_changes?)
Output only.
-
#latest_commit_id ⇒ String
Output only.
-
#latest_commit_time ⇒ String
Output only.
-
#name ⇒ String
Full name of the workspace resource, in the form of: projects/
project/ locations/location/conversionWorkspaces/conversion_workspace. -
#source ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
-
#source_provider ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversionWorkspace
constructor
A new instance of ConversionWorkspace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversionWorkspace
Returns a new instance of ConversionWorkspace.
1223 1224 1225 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the workspace resource was created.
Corresponds to the JSON property createTime
1159 1160 1161 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1159 def create_time @create_time end |
#destination ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
Corresponds to the JSON property destination
1164 1165 1166 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1164 def destination @destination end |
#destination_provider ⇒ String
Optional. The provider for the destination database.
Corresponds to the JSON property destinationProvider
1169 1170 1171 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1169 def destination_provider @destination_provider end |
#display_name ⇒ String
Optional. The display name for the workspace.
Corresponds to the JSON property displayName
1174 1175 1176 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1174 def display_name @display_name end |
#global_settings ⇒ Hash<String,String>
Optional. A generic list of settings for the workspace. The settings are
database pair dependant and can indicate default behavior for the mapping
rules engine or turn on or off specific features. Such examples can be:
convert_foreign_key_to_interleave=true, skip_triggers=false,
ignore_non_table_synonyms=true
Corresponds to the JSON property globalSettings
1183 1184 1185 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1183 def global_settings @global_settings end |
#has_uncommitted_changes ⇒ Boolean Also known as: has_uncommitted_changes?
Output only. Whether the workspace has uncommitted changes (changes which were
made after the workspace was committed).
Corresponds to the JSON property hasUncommittedChanges
1189 1190 1191 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1189 def has_uncommitted_changes @has_uncommitted_changes end |
#latest_commit_id ⇒ String
Output only. The latest commit ID.
Corresponds to the JSON property latestCommitId
1195 1196 1197 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1195 def latest_commit_id @latest_commit_id end |
#latest_commit_time ⇒ String
Output only. The timestamp when the workspace was committed.
Corresponds to the JSON property latestCommitTime
1200 1201 1202 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1200 def latest_commit_time @latest_commit_time end |
#name ⇒ String
Full name of the workspace resource, in the form of: projects/project/
locations/location/conversionWorkspaces/conversion_workspace.
Corresponds to the JSON property name
1206 1207 1208 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1206 def name @name end |
#source ⇒ Google::Apis::DatamigrationV1::DatabaseEngineInfo
The type and version of a source or destination database.
Corresponds to the JSON property source
1211 1212 1213 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1211 def source @source end |
#source_provider ⇒ String
Optional. The provider for the source database.
Corresponds to the JSON property sourceProvider
1216 1217 1218 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1216 def source_provider @source_provider end |
#update_time ⇒ String
Output only. The timestamp when the workspace resource was last updated.
Corresponds to the JSON property updateTime
1221 1222 1223 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1221 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1228 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @destination = args[:destination] if args.key?(:destination) @destination_provider = args[:destination_provider] if args.key?(:destination_provider) @display_name = args[:display_name] if args.key?(:display_name) @global_settings = args[:global_settings] if args.key?(:global_settings) @has_uncommitted_changes = args[:has_uncommitted_changes] if args.key?(:has_uncommitted_changes) @latest_commit_id = args[:latest_commit_id] if args.key?(:latest_commit_id) @latest_commit_time = args[:latest_commit_time] if args.key?(:latest_commit_time) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @source_provider = args[:source_provider] if args.key?(:source_provider) @update_time = args[:update_time] if args.key?(:update_time) end |