Class: Google::Apis::DatamigrationV1::DataCacheConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::DataCacheConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Data cache is an optional feature available for Cloud SQL for MySQL Enterprise Plus edition only. For more information on data cache, see Data cache overview in Cloud SQL documentation.
Instance Attribute Summary collapse
-
#data_cache_enabled ⇒ Boolean
(also: #data_cache_enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataCacheConfig
constructor
A new instance of DataCacheConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataCacheConfig
Returns a new instance of DataCacheConfig.
1383 1384 1385 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_cache_enabled ⇒ Boolean Also known as: data_cache_enabled?
Optional. Whether data cache is enabled for the instance.
Corresponds to the JSON property dataCacheEnabled
1380 1381 1382 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1380 def data_cache_enabled @data_cache_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1388 1389 1390 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1388 def update!(**args) @data_cache_enabled = args[:data_cache_enabled] if args.key?(:data_cache_enabled) end |