Class: Google::Apis::DatamigrationV1::DataCacheConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::DataCacheConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Data cache is an optional feature available for Cloud SQL for MySQL Enterprise Plus edition only. For more information on data cache, see Data cache overview in Cloud SQL documentation.
Instance Attribute Summary collapse
-
#data_cache_enabled ⇒ Boolean
(also: #data_cache_enabled?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataCacheConfig
constructor
A new instance of DataCacheConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataCacheConfig
Returns a new instance of DataCacheConfig.
1363 1364 1365 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_cache_enabled ⇒ Boolean Also known as: data_cache_enabled?
Optional. Whether data cache is enabled for the instance.
Corresponds to the JSON property dataCacheEnabled
1360 1361 1362 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1360 def data_cache_enabled @data_cache_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1368 1369 1370 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1368 def update!(**args) @data_cache_enabled = args[:data_cache_enabled] if args.key?(:data_cache_enabled) end |