Class: Google::Apis::DatamigrationV1::EntityMapping
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::EntityMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Details of the mappings of a database entity.
Instance Attribute Summary collapse
-
#draft_entity ⇒ String
Target entity full name.
-
#draft_type ⇒ String
Type of draft entity.
-
#mapping_log ⇒ Array<Google::Apis::DatamigrationV1::EntityMappingLogEntry>
Entity mapping log entries.
-
#source_entity ⇒ String
Source entity full name.
-
#source_type ⇒ String
Type of source entity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EntityMapping
constructor
A new instance of EntityMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EntityMapping
Returns a new instance of EntityMapping.
1893 1894 1895 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#draft_entity ⇒ String
Target entity full name. The draft entity can also include a column, index or
constraint using the same naming notation schema.table.column.
Corresponds to the JSON property draftEntity
1866 1867 1868 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1866 def draft_entity @draft_entity end |
#draft_type ⇒ String
Type of draft entity.
Corresponds to the JSON property draftType
1871 1872 1873 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1871 def draft_type @draft_type end |
#mapping_log ⇒ Array<Google::Apis::DatamigrationV1::EntityMappingLogEntry>
Entity mapping log entries. Multiple rules can be effective and contribute
changes to a converted entity, such as a rule can handle the entity name,
another rule can handle an entity type. In addition, rules which did not
change the entity are also logged along with the reason preventing them to do
so.
Corresponds to the JSON property mappingLog
1880 1881 1882 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1880 def mapping_log @mapping_log end |
#source_entity ⇒ String
Source entity full name. The source entity can also be a column, index or
constraint using the same naming notation schema.table.column.
Corresponds to the JSON property sourceEntity
1886 1887 1888 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1886 def source_entity @source_entity end |
#source_type ⇒ String
Type of source entity.
Corresponds to the JSON property sourceType
1891 1892 1893 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1891 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 1898 def update!(**args) @draft_entity = args[:draft_entity] if args.key?(:draft_entity) @draft_type = args[:draft_type] if args.key?(:draft_type) @mapping_log = args[:mapping_log] if args.key?(:mapping_log) @source_entity = args[:source_entity] if args.key?(:source_entity) @source_type = args[:source_type] if args.key?(:source_type) end |