Class: Google::Apis::DatamigrationV1::IndexEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Index is not used as an independent entity, it is retrieved as part of a Table entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexEntity

Returns a new instance of IndexEntity.



2400
2401
2402
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2400

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_featuresHash<String,Object>

Custom engine specific features. Corresponds to the JSON property customFeatures

Returns:

  • (Hash<String,Object>)


2367
2368
2369
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2367

def custom_features
  @custom_features
end

#nameString

The name of the index. Corresponds to the JSON property name

Returns:

  • (String)


2372
2373
2374
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2372

def name
  @name
end

#table_columnsArray<String>

Table columns used as part of the Index, for example B-TREE index should list the columns which constitutes the index. Corresponds to the JSON property tableColumns

Returns:

  • (Array<String>)


2378
2379
2380
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2378

def table_columns
  @table_columns
end

#table_columns_descendingArray<Boolean>

For each table_column, mark whether it's sorting order is ascending (false) or descending (true). If no value is defined, assume all columns are sorted in ascending order. Otherwise, the number of items must match that of table_columns with each value specifying the direction of the matched column by its index. Corresponds to the JSON property tableColumnsDescending

Returns:

  • (Array<Boolean>)


2387
2388
2389
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2387

def table_columns_descending
  @table_columns_descending
end

#typeString

Type of index, for example B-TREE. Corresponds to the JSON property type

Returns:

  • (String)


2392
2393
2394
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2392

def type
  @type
end

#uniqueBoolean Also known as: unique?

Boolean value indicating whether the index is unique. Corresponds to the JSON property unique

Returns:

  • (Boolean)


2397
2398
2399
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2397

def unique
  @unique
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2405
2406
2407
2408
2409
2410
2411
2412
# File 'lib/google/apis/datamigration_v1/classes.rb', line 2405

def update!(**args)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @name = args[:name] if args.key?(:name)
  @table_columns = args[:table_columns] if args.key?(:table_columns)
  @table_columns_descending = args[:table_columns_descending] if args.key?(:table_columns_descending)
  @type = args[:type] if args.key?(:type)
  @unique = args[:unique] if args.key?(:unique)
end