Class: Google::Apis::DatamigrationV1::MappingRuleFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A filter defining the entities that a mapping rule should be applied to. When more than one field is specified, the rule is applied only to entities which match all the fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MappingRuleFilter

Returns a new instance of MappingRuleFilter.



3281
3282
3283
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitiesArray<String>

Optional. The rule should be applied to specific entities defined by their fully qualified names. Corresponds to the JSON property entities

Returns:

  • (Array<String>)


3252
3253
3254
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3252

def entities
  @entities
end

#entity_name_containsString

Optional. The rule should be applied to entities whose non-qualified name contains the given string. Corresponds to the JSON property entityNameContains

Returns:

  • (String)


3258
3259
3260
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3258

def entity_name_contains
  @entity_name_contains
end

#entity_name_prefixString

Optional. The rule should be applied to entities whose non-qualified name starts with the given prefix. Corresponds to the JSON property entityNamePrefix

Returns:

  • (String)


3264
3265
3266
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3264

def entity_name_prefix
  @entity_name_prefix
end

#entity_name_suffixString

Optional. The rule should be applied to entities whose non-qualified name ends with the given suffix. Corresponds to the JSON property entityNameSuffix

Returns:

  • (String)


3270
3271
3272
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3270

def entity_name_suffix
  @entity_name_suffix
end

#parent_entityString

Optional. The rule should be applied to entities whose parent entity (fully qualified name) matches the given value. For example, if the rule applies to a table entity, the expected value should be a schema (schema). If the rule applies to a column or index entity, the expected value can be either a schema (schema) or a table (schema.table) Corresponds to the JSON property parentEntity

Returns:

  • (String)


3279
3280
3281
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3279

def parent_entity
  @parent_entity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3286
3287
3288
3289
3290
3291
3292
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3286

def update!(**args)
  @entities = args[:entities] if args.key?(:entities)
  @entity_name_contains = args[:entity_name_contains] if args.key?(:entity_name_contains)
  @entity_name_prefix = args[:entity_name_prefix] if args.key?(:entity_name_prefix)
  @entity_name_suffix = args[:entity_name_suffix] if args.key?(:entity_name_suffix)
  @parent_entity = args[:parent_entity] if args.key?(:parent_entity)
end