Class: Google::Apis::DatamigrationV1::MappingRuleFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A filter defining the entities that a mapping rule should be applied to. When more than one field is specified, the rule is applied only to entities which match all the fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MappingRuleFilter

Returns a new instance of MappingRuleFilter.



3055
3056
3057
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entitiesArray<String>

Optional. The rule should be applied to specific entities defined by their fully qualified names. Corresponds to the JSON property entities

Returns:

  • (Array<String>)


3026
3027
3028
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3026

def entities
  @entities
end

#entity_name_containsString

Optional. The rule should be applied to entities whose non-qualified name contains the given string. Corresponds to the JSON property entityNameContains

Returns:

  • (String)


3032
3033
3034
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3032

def entity_name_contains
  @entity_name_contains
end

#entity_name_prefixString

Optional. The rule should be applied to entities whose non-qualified name starts with the given prefix. Corresponds to the JSON property entityNamePrefix

Returns:

  • (String)


3038
3039
3040
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3038

def entity_name_prefix
  @entity_name_prefix
end

#entity_name_suffixString

Optional. The rule should be applied to entities whose non-qualified name ends with the given suffix. Corresponds to the JSON property entityNameSuffix

Returns:

  • (String)


3044
3045
3046
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3044

def entity_name_suffix
  @entity_name_suffix
end

#parent_entityString

Optional. The rule should be applied to entities whose parent entity (fully qualified name) matches the given value. For example, if the rule applies to a table entity, the expected value should be a schema (schema). If the rule applies to a column or index entity, the expected value can be either a schema (schema) or a table (schema.table) Corresponds to the JSON property parentEntity

Returns:

  • (String)


3053
3054
3055
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3053

def parent_entity
  @parent_entity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3060
3061
3062
3063
3064
3065
3066
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3060

def update!(**args)
  @entities = args[:entities] if args.key?(:entities)
  @entity_name_contains = args[:entity_name_contains] if args.key?(:entity_name_contains)
  @entity_name_prefix = args[:entity_name_prefix] if args.key?(:entity_name_prefix)
  @entity_name_suffix = args[:entity_name_suffix] if args.key?(:entity_name_suffix)
  @parent_entity = args[:parent_entity] if args.key?(:parent_entity)
end