Class: Google::Apis::DatamigrationV1::MigrationJobObject
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::MigrationJobObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
A specific Migration Job Object (e.g. a specifc DB Table)
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::DatamigrationV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#heterogeneous_metadata ⇒ Google::Apis::DatamigrationV1::HeterogeneousMetadata
Metadata for heterogeneous migration jobs objects.
-
#name ⇒ String
The object's name.
-
#phase ⇒ String
Output only.
-
#source_object ⇒ Google::Apis::DatamigrationV1::SourceObjectIdentifier
An identifier for the Migration Job Object.
-
#state ⇒ String
The state of the migration job object.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MigrationJobObject
constructor
A new instance of MigrationJobObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MigrationJobObject
Returns a new instance of MigrationJobObject.
3649 3650 3651 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation time of the migration job object.
Corresponds to the JSON property createTime
3607 3608 3609 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3607 def create_time @create_time end |
#error ⇒ Google::Apis::DatamigrationV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
3617 3618 3619 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3617 def error @error end |
#heterogeneous_metadata ⇒ Google::Apis::DatamigrationV1::HeterogeneousMetadata
Metadata for heterogeneous migration jobs objects.
Corresponds to the JSON property heterogeneousMetadata
3622 3623 3624 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3622 def @heterogeneous_metadata end |
#name ⇒ String
The object's name.
Corresponds to the JSON property name
3627 3628 3629 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3627 def name @name end |
#phase ⇒ String
Output only. The phase of the migration job object.
Corresponds to the JSON property phase
3632 3633 3634 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3632 def phase @phase end |
#source_object ⇒ Google::Apis::DatamigrationV1::SourceObjectIdentifier
An identifier for the Migration Job Object.
Corresponds to the JSON property sourceObject
3637 3638 3639 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3637 def source_object @source_object end |
#state ⇒ String
The state of the migration job object.
Corresponds to the JSON property state
3642 3643 3644 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3642 def state @state end |
#update_time ⇒ String
Output only. The last update time of the migration job object.
Corresponds to the JSON property updateTime
3647 3648 3649 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3647 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3654 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @error = args[:error] if args.key?(:error) @heterogeneous_metadata = args[:heterogeneous_metadata] if args.key?(:heterogeneous_metadata) @name = args[:name] if args.key?(:name) @phase = args[:phase] if args.key?(:phase) @source_object = args[:source_object] if args.key?(:source_object) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |