Class: Google::Apis::DatamigrationV1::MigrationJobObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A specific Migration Job Object (e.g. a specifc DB Table)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationJobObject

Returns a new instance of MigrationJobObject.



3648
3649
3650
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation time of the migration job object. Corresponds to the JSON property createTime

Returns:

  • (String)


3606
3607
3608
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3606

def create_time
  @create_time
end

#errorGoogle::Apis::DatamigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3616
3617
3618
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3616

def error
  @error
end

#heterogeneous_metadataGoogle::Apis::DatamigrationV1::HeterogeneousMetadata

Metadata for heterogeneous migration jobs objects. Corresponds to the JSON property heterogeneousMetadata



3621
3622
3623
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3621

def 
  @heterogeneous_metadata
end

#nameString

The object's name. Corresponds to the JSON property name

Returns:

  • (String)


3626
3627
3628
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3626

def name
  @name
end

#phaseString

Output only. The phase of the migration job object. Corresponds to the JSON property phase

Returns:

  • (String)


3631
3632
3633
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3631

def phase
  @phase
end

#source_objectGoogle::Apis::DatamigrationV1::SourceObjectIdentifier

An identifier for the Migration Job Object. Corresponds to the JSON property sourceObject



3636
3637
3638
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3636

def source_object
  @source_object
end

#stateString

The state of the migration job object. Corresponds to the JSON property state

Returns:

  • (String)


3641
3642
3643
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3641

def state
  @state
end

#update_timeString

Output only. The last update time of the migration job object. Corresponds to the JSON property updateTime

Returns:

  • (String)


3646
3647
3648
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3646

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3653

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @heterogeneous_metadata = args[:heterogeneous_metadata] if args.key?(:heterogeneous_metadata)
  @name = args[:name] if args.key?(:name)
  @phase = args[:phase] if args.key?(:phase)
  @source_object = args[:source_object] if args.key?(:source_object)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end