Class: Google::Apis::DatamigrationV1::MigrationJobObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A specific Migration Job Object (e.g. a specifc DB Table)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationJobObject

Returns a new instance of MigrationJobObject.



3636
3637
3638
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation time of the migration job object. Corresponds to the JSON property createTime

Returns:

  • (String)


3594
3595
3596
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3594

def create_time
  @create_time
end

#errorGoogle::Apis::DatamigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3604
3605
3606
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3604

def error
  @error
end

#heterogeneous_metadataGoogle::Apis::DatamigrationV1::HeterogeneousMetadata

Metadata for heterogeneous migration jobs objects. Corresponds to the JSON property heterogeneousMetadata



3609
3610
3611
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3609

def 
  @heterogeneous_metadata
end

#nameString

The object's name. Corresponds to the JSON property name

Returns:

  • (String)


3614
3615
3616
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3614

def name
  @name
end

#phaseString

Output only. The phase of the migration job object. Corresponds to the JSON property phase

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3619

def phase
  @phase
end

#source_objectGoogle::Apis::DatamigrationV1::SourceObjectIdentifier

An identifier for the Migration Job Object. Corresponds to the JSON property sourceObject



3624
3625
3626
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3624

def source_object
  @source_object
end

#stateString

The state of the migration job object. Corresponds to the JSON property state

Returns:

  • (String)


3629
3630
3631
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3629

def state
  @state
end

#update_timeString

Output only. The last update time of the migration job object. Corresponds to the JSON property updateTime

Returns:

  • (String)


3634
3635
3636
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3634

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3641
3642
3643
3644
3645
3646
3647
3648
3649
3650
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3641

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @heterogeneous_metadata = args[:heterogeneous_metadata] if args.key?(:heterogeneous_metadata)
  @name = args[:name] if args.key?(:name)
  @phase = args[:phase] if args.key?(:phase)
  @source_object = args[:source_object] if args.key?(:source_object)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end