Class: Google::Apis::DatamigrationV1::MigrationJobObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

A specific Migration Job Object (e.g. a specifc DB Table)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationJobObject

Returns a new instance of MigrationJobObject.



3410
3411
3412
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation time of the migration job object. Corresponds to the JSON property createTime

Returns:

  • (String)


3368
3369
3370
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3368

def create_time
  @create_time
end

#errorGoogle::Apis::DatamigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3378
3379
3380
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3378

def error
  @error
end

#heterogeneous_metadataGoogle::Apis::DatamigrationV1::HeterogeneousMetadata

Metadata for heterogeneous migration jobs objects. Corresponds to the JSON property heterogeneousMetadata



3383
3384
3385
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3383

def 
  @heterogeneous_metadata
end

#nameString

The object's name. Corresponds to the JSON property name

Returns:

  • (String)


3388
3389
3390
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3388

def name
  @name
end

#phaseString

Output only. The phase of the migration job object. Corresponds to the JSON property phase

Returns:

  • (String)


3393
3394
3395
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3393

def phase
  @phase
end

#source_objectGoogle::Apis::DatamigrationV1::SourceObjectIdentifier

An identifier for the Migration Job Object. Corresponds to the JSON property sourceObject



3398
3399
3400
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3398

def source_object
  @source_object
end

#stateString

The state of the migration job object. Corresponds to the JSON property state

Returns:

  • (String)


3403
3404
3405
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3403

def state
  @state
end

#update_timeString

Output only. The last update time of the migration job object. Corresponds to the JSON property updateTime

Returns:

  • (String)


3408
3409
3410
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3408

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3415

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @heterogeneous_metadata = args[:heterogeneous_metadata] if args.key?(:heterogeneous_metadata)
  @name = args[:name] if args.key?(:name)
  @phase = args[:phase] if args.key?(:phase)
  @source_object = args[:source_object] if args.key?(:source_object)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end