Class: Google::Apis::DatamigrationV1::MySqlConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::MySqlConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Specifies connection parameters required specifically for MySQL databases.
Instance Attribute Summary collapse
-
#cloud_sql_id ⇒ String
If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source.
-
#host ⇒ String
Required.
-
#password ⇒ String
Required.
-
#password_set ⇒ Boolean
(also: #password_set?)
Output only.
-
#port ⇒ Fixnum
Required.
-
#ssl ⇒ Google::Apis::DatamigrationV1::SslConfig
SSL configuration information.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MySqlConnectionProfile
constructor
A new instance of MySqlConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MySqlConnectionProfile
Returns a new instance of MySqlConnectionProfile.
3868 3869 3870 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3868 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql_id ⇒ String
If the source is a Cloud SQL database, use this field to provide the Cloud SQL
instance ID of the source.
Corresponds to the JSON property cloudSqlId
3831 3832 3833 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3831 def cloud_sql_id @cloud_sql_id end |
#host ⇒ String
Required. The IP or hostname of the source MySQL database.
Corresponds to the JSON property host
3836 3837 3838 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3836 def host @host end |
#password ⇒ String
Required. Input only. The password for the user that Database Migration
Service will be using to connect to the database. This field is not returned
on request, and the value is encrypted when stored in Database Migration
Service.
Corresponds to the JSON property password
3844 3845 3846 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3844 def password @password end |
#password_set ⇒ Boolean Also known as: password_set?
Output only. Indicates If this connection profile password is stored.
Corresponds to the JSON property passwordSet
3849 3850 3851 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3849 def password_set @password_set end |
#port ⇒ Fixnum
Required. The network port of the source MySQL database.
Corresponds to the JSON property port
3855 3856 3857 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3855 def port @port end |
#ssl ⇒ Google::Apis::DatamigrationV1::SslConfig
SSL configuration information.
Corresponds to the JSON property ssl
3860 3861 3862 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3860 def ssl @ssl end |
#username ⇒ String
Required. The username that Database Migration Service will use to connect to
the database. The value is encrypted when stored in Database Migration Service.
Corresponds to the JSON property username
3866 3867 3868 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3866 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3873 3874 3875 3876 3877 3878 3879 3880 3881 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3873 def update!(**args) @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_set = args[:password_set] if args.key?(:password_set) @port = args[:port] if args.key?(:port) @ssl = args[:ssl] if args.key?(:ssl) @username = args[:username] if args.key?(:username) end |