Class: Google::Apis::DatamigrationV1::MySqlConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for MySQL databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MySqlConnectionProfile

Returns a new instance of MySqlConnectionProfile.



3636
3637
3638
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_idString

If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source. Corresponds to the JSON property cloudSqlId

Returns:

  • (String)


3599
3600
3601
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3599

def cloud_sql_id
  @cloud_sql_id
end

#hostString

Required. The IP or hostname of the source MySQL database. Corresponds to the JSON property host

Returns:

  • (String)


3604
3605
3606
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3604

def host
  @host
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


3612
3613
3614
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3612

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates If this connection profile password is stored. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


3617
3618
3619
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3617

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source MySQL database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


3623
3624
3625
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3623

def port
  @port
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



3628
3629
3630
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3628

def ssl
  @ssl
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


3634
3635
3636
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3634

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3641
3642
3643
3644
3645
3646
3647
3648
3649
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3641

def update!(**args)
  @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @ssl = args[:ssl] if args.key?(:ssl)
  @username = args[:username] if args.key?(:username)
end