Class: Google::Apis::DatamigrationV1::OracleConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::OracleConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Specifies connection parameters required specifically for Oracle databases.
Instance Attribute Summary collapse
-
#database_service ⇒ String
Required.
-
#forward_ssh_connectivity ⇒ Google::Apis::DatamigrationV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
-
#host ⇒ String
Required.
-
#oracle_asm_config ⇒ Google::Apis::DatamigrationV1::OracleAsmConfig
Configuration for Oracle Automatic Storage Management (ASM) connection.
-
#password ⇒ String
Required.
-
#password_set ⇒ Boolean
(also: #password_set?)
Output only.
-
#port ⇒ Fixnum
Required.
-
#private_connectivity ⇒ Google::Apis::DatamigrationV1::PrivateConnectivity
Private Connectivity.
-
#ssl ⇒ Google::Apis::DatamigrationV1::SslConfig
SSL configuration information.
-
#static_service_ip_connectivity ⇒ Google::Apis::DatamigrationV1::StaticServiceIpConnectivity
Static IP address connectivity configured on service project.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OracleConnectionProfile
constructor
A new instance of OracleConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OracleConnectionProfile
Returns a new instance of OracleConnectionProfile.
4106 4107 4108 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_service ⇒ String
Required. Database service for the Oracle connection.
Corresponds to the JSON property databaseService
4049 4050 4051 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4049 def database_service @database_service end |
#forward_ssh_connectivity ⇒ Google::Apis::DatamigrationV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
Corresponds to the JSON property forwardSshConnectivity
4054 4055 4056 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4054 def forward_ssh_connectivity @forward_ssh_connectivity end |
#host ⇒ String
Required. The IP or hostname of the source Oracle database.
Corresponds to the JSON property host
4059 4060 4061 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4059 def host @host end |
#oracle_asm_config ⇒ Google::Apis::DatamigrationV1::OracleAsmConfig
Configuration for Oracle Automatic Storage Management (ASM) connection.
Corresponds to the JSON property oracleAsmConfig
4064 4065 4066 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4064 def oracle_asm_config @oracle_asm_config end |
#password ⇒ String
Required. Input only. The password for the user that Database Migration
Service will be using to connect to the database. This field is not returned
on request, and the value is encrypted when stored in Database Migration
Service.
Corresponds to the JSON property password
4072 4073 4074 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4072 def password @password end |
#password_set ⇒ Boolean Also known as: password_set?
Output only. Indicates whether a new password is included in the request.
Corresponds to the JSON property passwordSet
4077 4078 4079 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4077 def password_set @password_set end |
#port ⇒ Fixnum
Required. The network port of the source Oracle database.
Corresponds to the JSON property port
4083 4084 4085 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4083 def port @port end |
#private_connectivity ⇒ Google::Apis::DatamigrationV1::PrivateConnectivity
Private Connectivity.
Corresponds to the JSON property privateConnectivity
4088 4089 4090 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4088 def private_connectivity @private_connectivity end |
#ssl ⇒ Google::Apis::DatamigrationV1::SslConfig
SSL configuration information.
Corresponds to the JSON property ssl
4093 4094 4095 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4093 def ssl @ssl end |
#static_service_ip_connectivity ⇒ Google::Apis::DatamigrationV1::StaticServiceIpConnectivity
Static IP address connectivity configured on service project.
Corresponds to the JSON property staticServiceIpConnectivity
4098 4099 4100 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4098 def static_service_ip_connectivity @static_service_ip_connectivity end |
#username ⇒ String
Required. The username that Database Migration Service will use to connect to
the database. The value is encrypted when stored in Database Migration Service.
Corresponds to the JSON property username
4104 4105 4106 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4104 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4111 def update!(**args) @database_service = args[:database_service] if args.key?(:database_service) @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity) @host = args[:host] if args.key?(:host) @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config) @password = args[:password] if args.key?(:password) @password_set = args[:password_set] if args.key?(:password_set) @port = args[:port] if args.key?(:port) @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity) @ssl = args[:ssl] if args.key?(:ssl) @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity) @username = args[:username] if args.key?(:username) end |