Class: Google::Apis::DatamigrationV1::OracleConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for Oracle databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleConnectionProfile

Returns a new instance of OracleConnectionProfile.



4079
4080
4081
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_serviceString

Required. Database service for the Oracle connection. Corresponds to the JSON property databaseService

Returns:

  • (String)


4022
4023
4024
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4022

def database_service
  @database_service
end

#forward_ssh_connectivityGoogle::Apis::DatamigrationV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



4027
4028
4029
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4027

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#hostString

Required. The IP or hostname of the source Oracle database. Corresponds to the JSON property host

Returns:

  • (String)


4032
4033
4034
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4032

def host
  @host
end

#oracle_asm_configGoogle::Apis::DatamigrationV1::OracleAsmConfig

Configuration for Oracle Automatic Storage Management (ASM) connection. Corresponds to the JSON property oracleAsmConfig



4037
4038
4039
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4037

def oracle_asm_config
  @oracle_asm_config
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4045

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates whether a new password is included in the request. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


4050
4051
4052
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4050

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source Oracle database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


4056
4057
4058
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4056

def port
  @port
end

#private_connectivityGoogle::Apis::DatamigrationV1::PrivateConnectivity

Private Connectivity. Corresponds to the JSON property privateConnectivity



4061
4062
4063
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4061

def private_connectivity
  @private_connectivity
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



4066
4067
4068
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4066

def ssl
  @ssl
end

#static_service_ip_connectivityGoogle::Apis::DatamigrationV1::StaticServiceIpConnectivity

Static IP address connectivity configured on service project. Corresponds to the JSON property staticServiceIpConnectivity



4071
4072
4073
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4071

def static_service_ip_connectivity
  @static_service_ip_connectivity
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4077

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
4096
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4084

def update!(**args)
  @database_service = args[:database_service] if args.key?(:database_service)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @host = args[:host] if args.key?(:host)
  @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @ssl = args[:ssl] if args.key?(:ssl)
  @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity)
  @username = args[:username] if args.key?(:username)
end