Class: Google::Apis::DatamigrationV1::OracleConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for Oracle databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OracleConnectionProfile

Returns a new instance of OracleConnectionProfile.



3847
3848
3849
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_serviceString

Required. Database service for the Oracle connection. Corresponds to the JSON property databaseService

Returns:

  • (String)


3790
3791
3792
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3790

def database_service
  @database_service
end

#forward_ssh_connectivityGoogle::Apis::DatamigrationV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



3795
3796
3797
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3795

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#hostString

Required. The IP or hostname of the source Oracle database. Corresponds to the JSON property host

Returns:

  • (String)


3800
3801
3802
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3800

def host
  @host
end

#oracle_asm_configGoogle::Apis::DatamigrationV1::OracleAsmConfig

Configuration for Oracle Automatic Storage Management (ASM) connection. Corresponds to the JSON property oracleAsmConfig



3805
3806
3807
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3805

def oracle_asm_config
  @oracle_asm_config
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


3813
3814
3815
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3813

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates whether a new password is included in the request. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


3818
3819
3820
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3818

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source Oracle database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


3824
3825
3826
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3824

def port
  @port
end

#private_connectivityGoogle::Apis::DatamigrationV1::PrivateConnectivity

Private Connectivity. Corresponds to the JSON property privateConnectivity



3829
3830
3831
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3829

def private_connectivity
  @private_connectivity
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



3834
3835
3836
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3834

def ssl
  @ssl
end

#static_service_ip_connectivityGoogle::Apis::DatamigrationV1::StaticServiceIpConnectivity

Static IP address connectivity configured on service project. Corresponds to the JSON property staticServiceIpConnectivity



3839
3840
3841
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3839

def static_service_ip_connectivity
  @static_service_ip_connectivity
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


3845
3846
3847
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3845

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3852

def update!(**args)
  @database_service = args[:database_service] if args.key?(:database_service)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @host = args[:host] if args.key?(:host)
  @oracle_asm_config = args[:oracle_asm_config] if args.key?(:oracle_asm_config)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @ssl = args[:ssl] if args.key?(:ssl)
  @static_service_ip_connectivity = args[:static_service_ip_connectivity] if args.key?(:static_service_ip_connectivity)
  @username = args[:username] if args.key?(:username)
end