Class: Google::Apis::DatamigrationV1::OracleSourceConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::OracleSourceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Configuration for Oracle as a source in a migration.
Instance Attribute Summary collapse
-
#binary_log_parser ⇒ Google::Apis::DatamigrationV1::BinaryLogParser
Configuration to use Binary Log Parser CDC technique.
-
#cdc_start_position ⇒ Fixnum
Optional.
-
#log_miner ⇒ Google::Apis::DatamigrationV1::LogMiner
Configuration to use LogMiner CDC method.
-
#max_concurrent_cdc_connections ⇒ Fixnum
Optional.
-
#max_concurrent_full_dump_connections ⇒ Fixnum
Optional.
-
#skip_full_dump ⇒ Boolean
(also: #skip_full_dump?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OracleSourceConfig
constructor
A new instance of OracleSourceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OracleSourceConfig
Returns a new instance of OracleSourceConfig.
3904 3905 3906 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binary_log_parser ⇒ Google::Apis::DatamigrationV1::BinaryLogParser
Configuration to use Binary Log Parser CDC technique.
Corresponds to the JSON property binaryLogParser
3874 3875 3876 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3874 def binary_log_parser @binary_log_parser end |
#cdc_start_position ⇒ Fixnum
Optional. The schema change number (SCN) to start CDC data migration from.
Corresponds to the JSON property cdcStartPosition
3879 3880 3881 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3879 def cdc_start_position @cdc_start_position end |
#log_miner ⇒ Google::Apis::DatamigrationV1::LogMiner
Configuration to use LogMiner CDC method.
Corresponds to the JSON property logMiner
3884 3885 3886 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3884 def log_miner @log_miner end |
#max_concurrent_cdc_connections ⇒ Fixnum
Optional. Maximum number of connections Database Migration Service will open
to the source for CDC phase.
Corresponds to the JSON property maxConcurrentCdcConnections
3890 3891 3892 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3890 def max_concurrent_cdc_connections @max_concurrent_cdc_connections end |
#max_concurrent_full_dump_connections ⇒ Fixnum
Optional. Maximum number of connections Database Migration Service will open
to the source for full dump phase.
Corresponds to the JSON property maxConcurrentFullDumpConnections
3896 3897 3898 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3896 def max_concurrent_full_dump_connections @max_concurrent_full_dump_connections end |
#skip_full_dump ⇒ Boolean Also known as: skip_full_dump?
Optional. Whether to skip full dump or not.
Corresponds to the JSON property skipFullDump
3901 3902 3903 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3901 def skip_full_dump @skip_full_dump end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3909 3910 3911 3912 3913 3914 3915 3916 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 3909 def update!(**args) @binary_log_parser = args[:binary_log_parser] if args.key?(:binary_log_parser) @cdc_start_position = args[:cdc_start_position] if args.key?(:cdc_start_position) @log_miner = args[:log_miner] if args.key?(:log_miner) @max_concurrent_cdc_connections = args[:max_concurrent_cdc_connections] if args.key?(:max_concurrent_cdc_connections) @max_concurrent_full_dump_connections = args[:max_concurrent_full_dump_connections] if args.key?(:max_concurrent_full_dump_connections) @skip_full_dump = args[:skip_full_dump] if args.key?(:skip_full_dump) end |