Class: Google::Apis::DatamigrationV1::PostgreSqlConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for PostgreSQL databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PostgreSqlConnectionProfile

Returns a new instance of PostgreSqlConnectionProfile.



4440
4441
4442
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alloydb_cluster_idString

Optional. If the destination is an AlloyDB database, use this field to provide the AlloyDB cluster ID. Corresponds to the JSON property alloydbClusterId

Returns:

  • (String)


4362
4363
4364
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4362

def alloydb_cluster_id
  @alloydb_cluster_id
end

#cloud_sql_idString

If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source. Corresponds to the JSON property cloudSqlId

Returns:

  • (String)


4368
4369
4370
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4368

def cloud_sql_id
  @cloud_sql_id
end

#databaseString

Optional. The name of the specific database within the host. Corresponds to the JSON property database

Returns:

  • (String)


4373
4374
4375
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4373

def database
  @database
end

#forward_ssh_connectivityGoogle::Apis::DatamigrationV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



4378
4379
4380
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4378

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#hostString

Required. The IP or hostname of the source PostgreSQL database. Corresponds to the JSON property host

Returns:

  • (String)


4383
4384
4385
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4383

def host
  @host
end

#network_architectureString

Output only. If the source is a Cloud SQL database, this field indicates the network architecture it's associated with. Corresponds to the JSON property networkArchitecture

Returns:

  • (String)


4389
4390
4391
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4389

def network_architecture
  @network_architecture
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


4397
4398
4399
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4397

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates If this connection profile password is stored. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


4402
4403
4404
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4402

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source PostgreSQL database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


4408
4409
4410
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4408

def port
  @port
end

#private_connectivityGoogle::Apis::DatamigrationV1::PrivateConnectivity

Private Connectivity. Corresponds to the JSON property privateConnectivity



4413
4414
4415
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4413

def private_connectivity
  @private_connectivity
end

#private_service_connect_connectivityGoogle::Apis::DatamigrationV1::PrivateServiceConnectConnectivity

Private Service Connect connectivity Corresponds to the JSON property privateServiceConnectConnectivity



4419
4420
4421
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4419

def private_service_connect_connectivity
  @private_service_connect_connectivity
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



4424
4425
4426
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4424

def ssl
  @ssl
end

#static_ip_connectivityGoogle::Apis::DatamigrationV1::StaticIpConnectivity

The source database will allow incoming connections from the public IP of the destination database. You can retrieve the public IP of the Cloud SQL instance from the Cloud SQL console or using Cloud SQL APIs. No additional configuration is required. Corresponds to the JSON property staticIpConnectivity



4432
4433
4434
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4432

def static_ip_connectivity
  @static_ip_connectivity
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


4438
4439
4440
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4438

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4445

def update!(**args)
  @alloydb_cluster_id = args[:alloydb_cluster_id] if args.key?(:alloydb_cluster_id)
  @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id)
  @database = args[:database] if args.key?(:database)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @host = args[:host] if args.key?(:host)
  @network_architecture = args[:network_architecture] if args.key?(:network_architecture)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @private_service_connect_connectivity = args[:private_service_connect_connectivity] if args.key?(:private_service_connect_connectivity)
  @ssl = args[:ssl] if args.key?(:ssl)
  @static_ip_connectivity = args[:static_ip_connectivity] if args.key?(:static_ip_connectivity)
  @username = args[:username] if args.key?(:username)
end