Class: Google::Apis::DatamigrationV1::PrivateConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

The PrivateConnection resource is used to establish private connectivity with the customer's network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateConnection

Returns a new instance of PrivateConnection.



4792
4793
4794
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The create time of the resource. Corresponds to the JSON property createTime

Returns:

  • (String)


4728
4729
4730
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4728

def create_time
  @create_time
end

#display_nameString

The private connection display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4733
4734
4735
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4733

def display_name
  @display_name
end

#errorGoogle::Apis::DatamigrationV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4743
4744
4745
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4743

def error
  @error
end

#labelsHash<String,String>

The resource labels for private connections to use to annotate any related underlying resources such as Compute Engine VMs. An object containing a list of "key": "value" pairs. Example: "name": "wrench", "mass": "1.3kg", "count" : "3". Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4751
4752
4753
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4751

def labels
  @labels
end

#nameString

The name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


4756
4757
4758
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4756

def name
  @name
end

#psc_interface_configGoogle::Apis::DatamigrationV1::PscInterfaceConfig

The PSC Interface configuration is used to create PSC Interface between DMS's internal VPC and the consumer's PSC. Corresponds to the JSON property pscInterfaceConfig



4762
4763
4764
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4762

def psc_interface_config
  @psc_interface_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


4767
4768
4769
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4767

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


4773
4774
4775
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4773

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of the private connection. Corresponds to the JSON property state

Returns:

  • (String)


4779
4780
4781
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4779

def state
  @state
end

#update_timeString

Output only. The last update time of the resource. Corresponds to the JSON property updateTime

Returns:

  • (String)


4784
4785
4786
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4784

def update_time
  @update_time
end

#vpc_peering_configGoogle::Apis::DatamigrationV1::VpcPeeringConfig

The VPC peering configuration is used to create VPC peering with the consumer' s VPC. Corresponds to the JSON property vpcPeeringConfig



4790
4791
4792
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4790

def vpc_peering_config
  @vpc_peering_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4797

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vpc_peering_config = args[:vpc_peering_config] if args.key?(:vpc_peering_config)
end