Class: Google::Apis::DatamigrationV1::PrivateConnection
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::PrivateConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
The PrivateConnection resource is used to establish private connectivity with the customer's network.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The private connection display name.
-
#error ⇒ Google::Apis::DatamigrationV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The resource labels for private connections to use to annotate any related underlying resources such as Compute Engine VMs.
-
#name ⇒ String
The name of the resource.
-
#psc_interface_config ⇒ Google::Apis::DatamigrationV1::PscInterfaceConfig
The PSC Interface configuration is used to create PSC Interface between DMS's internal VPC and the consumer's PSC.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vpc_peering_config ⇒ Google::Apis::DatamigrationV1::VpcPeeringConfig
The VPC peering configuration is used to create VPC peering with the consumer' s VPC.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrivateConnection
constructor
A new instance of PrivateConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrivateConnection
Returns a new instance of PrivateConnection.
4724 4725 4726 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The create time of the resource.
Corresponds to the JSON property createTime
4660 4661 4662 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4660 def create_time @create_time end |
#display_name ⇒ String
The private connection display name.
Corresponds to the JSON property displayName
4665 4666 4667 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4665 def display_name @display_name end |
#error ⇒ Google::Apis::DatamigrationV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4675 4676 4677 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4675 def error @error end |
#labels ⇒ Hash<String,String>
The resource labels for private connections to use to annotate any related
underlying resources such as Compute Engine VMs. An object containing a list
of "key": "value" pairs. Example: "name": "wrench", "mass": "1.3kg", "count"
: "3".
Corresponds to the JSON property labels
4683 4684 4685 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4683 def labels @labels end |
#name ⇒ String
The name of the resource.
Corresponds to the JSON property name
4688 4689 4690 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4688 def name @name end |
#psc_interface_config ⇒ Google::Apis::DatamigrationV1::PscInterfaceConfig
The PSC Interface configuration is used to create PSC Interface between DMS's
internal VPC and the consumer's PSC.
Corresponds to the JSON property pscInterfaceConfig
4694 4695 4696 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4694 def psc_interface_config @psc_interface_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
4699 4700 4701 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4699 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
4705 4706 4707 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4705 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of the private connection.
Corresponds to the JSON property state
4711 4712 4713 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4711 def state @state end |
#update_time ⇒ String
Output only. The last update time of the resource.
Corresponds to the JSON property updateTime
4716 4717 4718 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4716 def update_time @update_time end |
#vpc_peering_config ⇒ Google::Apis::DatamigrationV1::VpcPeeringConfig
The VPC peering configuration is used to create VPC peering with the consumer'
s VPC.
Corresponds to the JSON property vpcPeeringConfig
4722 4723 4724 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4722 def vpc_peering_config @vpc_peering_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4729 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @vpc_peering_config = args[:vpc_peering_config] if args.key?(:vpc_peering_config) end |