Class: Google::Apis::DatamigrationV1::RequestInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Contains metadata about the request that clients can attach when filing a bug or providing other forms of feedback.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequestInfo

Returns a new instance of RequestInfo.



5031
5032
5033
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

An opaque string that should only be interpreted by the service generating it. For example, it can be used to identify requests in the service's logs. Corresponds to the JSON property requestId

Returns:

  • (String)


5023
5024
5025
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5023

def request_id
  @request_id
end

#serving_dataString

Any data that was used to serve this request. For example, an encrypted stack trace that can be sent back to the service provider for debugging. Corresponds to the JSON property servingData

Returns:

  • (String)


5029
5030
5031
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5029

def serving_data
  @serving_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5036
5037
5038
5039
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5036

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @serving_data = args[:serving_data] if args.key?(:serving_data)
end