Class: Google::Apis::DatamigrationV1::ReverseSshConnectivity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::ReverseSshConnectivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
The details needed to configure a reverse SSH tunnel between the source and destination databases. These details will be used when calling the generateSshScript method (see https://cloud.google.com/database-migration/docs/ reference/rest/v1/projects.locations.migrationJobs/generateSshScript) to produce the script that will help set up the reverse SSH tunnel, and to set up the VPC peering between the Cloud SQL private network and the VPC.
Instance Attribute Summary collapse
-
#vm ⇒ String
The name of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel.
-
#vm_ip ⇒ String
Required.
-
#vm_port ⇒ Fixnum
Required.
-
#vpc ⇒ String
The name of the VPC to peer with the Cloud SQL private network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReverseSshConnectivity
constructor
A new instance of ReverseSshConnectivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReverseSshConnectivity
Returns a new instance of ReverseSshConnectivity.
4629 4630 4631 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#vm ⇒ String
The name of the virtual machine (Compute Engine) used as the bastion server
for the SSH tunnel.
Corresponds to the JSON property vm
4610 4611 4612 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4610 def vm @vm end |
#vm_ip ⇒ String
Required. The IP of the virtual machine (Compute Engine) used as the bastion
server for the SSH tunnel.
Corresponds to the JSON property vmIp
4616 4617 4618 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4616 def vm_ip @vm_ip end |
#vm_port ⇒ Fixnum
Required. The forwarding port of the virtual machine (Compute Engine) used as
the bastion server for the SSH tunnel.
Corresponds to the JSON property vmPort
4622 4623 4624 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4622 def vm_port @vm_port end |
#vpc ⇒ String
The name of the VPC to peer with the Cloud SQL private network.
Corresponds to the JSON property vpc
4627 4628 4629 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4627 def vpc @vpc end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4634 4635 4636 4637 4638 4639 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4634 def update!(**args) @vm = args[:vm] if args.key?(:vm) @vm_ip = args[:vm_ip] if args.key?(:vm_ip) @vm_port = args[:vm_port] if args.key?(:vm_port) @vpc = args[:vpc] if args.key?(:vpc) end |