Class: Google::Apis::DatamigrationV1::RulesFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Details of a single rules file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RulesFile

Returns a new instance of RulesFile.



5236
5237
5238
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rules_contentString

Required. The text content of the rules that needs to be converted. Corresponds to the JSON property rulesContent

Returns:

  • (String)


5227
5228
5229
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5227

def rules_content
  @rules_content
end

#rules_source_filenameString

Required. The filename of the rules that needs to be converted. The filename is used mainly so that future logs of the import rules job contain it, and can therefore be searched by it. Corresponds to the JSON property rulesSourceFilename

Returns:

  • (String)


5234
5235
5236
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5234

def rules_source_filename
  @rules_source_filename
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5241
5242
5243
5244
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5241

def update!(**args)
  @rules_content = args[:rules_content] if args.key?(:rules_content)
  @rules_source_filename = args[:rules_source_filename] if args.key?(:rules_source_filename)
end