Class: Google::Apis::DatamigrationV1::RulesFile
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::RulesFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Details of a single rules file.
Instance Attribute Summary collapse
-
#rules_content ⇒ String
Required.
-
#rules_source_filename ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RulesFile
constructor
A new instance of RulesFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RulesFile
Returns a new instance of RulesFile.
5195 5196 5197 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rules_content ⇒ String
Required. The text content of the rules that needs to be converted.
Corresponds to the JSON property rulesContent
5186 5187 5188 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5186 def rules_content @rules_content end |
#rules_source_filename ⇒ String
Required. The filename of the rules that needs to be converted. The filename
is used mainly so that future logs of the import rules job contain it, and can
therefore be searched by it.
Corresponds to the JSON property rulesSourceFilename
5193 5194 5195 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5193 def rules_source_filename @rules_source_filename end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5200 5201 5202 5203 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5200 def update!(**args) @rules_content = args[:rules_content] if args.key?(:rules_content) @rules_source_filename = args[:rules_source_filename] if args.key?(:rules_source_filename) end |