Class: Google::Apis::DatamigrationV1::RulesFile
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::RulesFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Details of a single rules file.
Instance Attribute Summary collapse
-
#rules_content ⇒ String
Required.
-
#rules_source_filename ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RulesFile
constructor
A new instance of RulesFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RulesFile
Returns a new instance of RulesFile.
4692 4693 4694 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rules_content ⇒ String
Required. The text content of the rules that needs to be converted.
Corresponds to the JSON property rulesContent
4683 4684 4685 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4683 def rules_content @rules_content end |
#rules_source_filename ⇒ String
Required. The filename of the rules that needs to be converted. The filename
is used mainly so that future logs of the import rules job contain it, and can
therefore be searched by it.
Corresponds to the JSON property rulesSourceFilename
4690 4691 4692 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4690 def rules_source_filename @rules_source_filename end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4697 4698 4699 4700 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4697 def update!(**args) @rules_content = args[:rules_content] if args.key?(:rules_content) @rules_source_filename = args[:rules_source_filename] if args.key?(:rules_source_filename) end |