Class: Google::Apis::DatamigrationV1::SequenceEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Sequence's parent is a schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SequenceEntity

Returns a new instance of SequenceEntity.



5346
5347
5348
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cacheFixnum

Indicates number of entries to cache / precreate. Corresponds to the JSON property cache

Returns:

  • (Fixnum)


5307
5308
5309
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5307

def cache
  @cache
end

#custom_featuresHash<String,Object>

Custom engine specific features. Corresponds to the JSON property customFeatures

Returns:

  • (Hash<String,Object>)


5312
5313
5314
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5312

def custom_features
  @custom_features
end

#cycleBoolean Also known as: cycle?

Indicates whether the sequence value should cycle through. Corresponds to the JSON property cycle

Returns:

  • (Boolean)


5317
5318
5319
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5317

def cycle
  @cycle
end

#incrementFixnum

Increment value for the sequence. Corresponds to the JSON property increment

Returns:

  • (Fixnum)


5323
5324
5325
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5323

def increment
  @increment
end

#max_valueString

Maximum number for the sequence represented as bytes to accommodate large. numbers Corresponds to the JSON property maxValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5330
5331
5332
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5330

def max_value
  @max_value
end

#min_valueString

Minimum number for the sequence represented as bytes to accommodate large. numbers Corresponds to the JSON property minValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5337
5338
5339
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5337

def min_value
  @min_value
end

#start_valueString

Start number for the sequence represented as bytes to accommodate large. numbers Corresponds to the JSON property startValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


5344
5345
5346
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5344

def start_value
  @start_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5351
5352
5353
5354
5355
5356
5357
5358
5359
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5351

def update!(**args)
  @cache = args[:cache] if args.key?(:cache)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @cycle = args[:cycle] if args.key?(:cycle)
  @increment = args[:increment] if args.key?(:increment)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @start_value = args[:start_value] if args.key?(:start_value)
end