Class: Google::Apis::DatamigrationV1::SingleColumnChange
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SingleColumnChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Options to configure rule type SingleColumnChange. The rule is used to change the properties of a column. The rule filter field can refer to one entity. The rule scope can be one of: Column. When using this rule, if a field is not specified than the destination column's configuration will be the same as the one in the source column..
Instance Attribute Summary collapse
-
#array ⇒ Boolean
(also: #array?)
Optional.
-
#array_length ⇒ Fixnum
Optional.
-
#auto_generated ⇒ Boolean
(also: #auto_generated?)
Optional.
-
#charset ⇒ String
Optional.
-
#collation ⇒ String
Optional.
-
#comment ⇒ String
Optional.
-
#custom_features ⇒ Hash<String,Object>
Optional.
-
#data_type ⇒ String
Optional.
-
#fractional_seconds_precision ⇒ Fixnum
Optional.
-
#length ⇒ Fixnum
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#precision ⇒ Fixnum
Optional.
-
#scale ⇒ Fixnum
Optional.
-
#set_values ⇒ Array<String>
Optional.
-
#udt ⇒ Boolean
(also: #udt?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleColumnChange
constructor
A new instance of SingleColumnChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleColumnChange
Returns a new instance of SingleColumnChange.
5539 5540 5541 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#array ⇒ Boolean Also known as: array?
Optional. Is the column of array type.
Corresponds to the JSON property array
5461 5462 5463 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5461 def array @array end |
#array_length ⇒ Fixnum
Optional. The length of the array, only relevant if the column type is an
array.
Corresponds to the JSON property arrayLength
5468 5469 5470 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5468 def array_length @array_length end |
#auto_generated ⇒ Boolean Also known as: auto_generated?
Optional. Is the column auto-generated/identity.
Corresponds to the JSON property autoGenerated
5473 5474 5475 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5473 def auto_generated @auto_generated end |
#charset ⇒ String
Optional. Charset override - instead of table level charset.
Corresponds to the JSON property charset
5479 5480 5481 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5479 def charset @charset end |
#collation ⇒ String
Optional. Collation override - instead of table level collation.
Corresponds to the JSON property collation
5484 5485 5486 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5484 def collation @collation end |
#comment ⇒ String
Optional. Comment associated with the column.
Corresponds to the JSON property comment
5489 5490 5491 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5489 def comment @comment end |
#custom_features ⇒ Hash<String,Object>
Optional. Custom engine specific features.
Corresponds to the JSON property customFeatures
5494 5495 5496 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5494 def custom_features @custom_features end |
#data_type ⇒ String
Optional. Column data type name.
Corresponds to the JSON property dataType
5499 5500 5501 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5499 def data_type @data_type end |
#fractional_seconds_precision ⇒ Fixnum
Optional. Column fractional seconds precision - e.g. 2 as in timestamp (2) -
when relevant.
Corresponds to the JSON property fractionalSecondsPrecision
5505 5506 5507 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5505 def fractional_seconds_precision @fractional_seconds_precision end |
#length ⇒ Fixnum
Optional. Column length - e.g. 50 as in varchar (50) - when relevant.
Corresponds to the JSON property length
5510 5511 5512 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5510 def length @length end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Is the column nullable.
Corresponds to the JSON property nullable
5515 5516 5517 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5515 def nullable @nullable end |
#precision ⇒ Fixnum
Optional. Column precision - e.g. 8 as in double (8,2) - when relevant.
Corresponds to the JSON property precision
5521 5522 5523 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5521 def precision @precision end |
#scale ⇒ Fixnum
Optional. Column scale - e.g. 2 as in double (8,2) - when relevant.
Corresponds to the JSON property scale
5526 5527 5528 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5526 def scale @scale end |
#set_values ⇒ Array<String>
Optional. Specifies the list of values allowed in the column.
Corresponds to the JSON property setValues
5531 5532 5533 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5531 def set_values @set_values end |
#udt ⇒ Boolean Also known as: udt?
Optional. Is the column a UDT (User-defined Type).
Corresponds to the JSON property udt
5536 5537 5538 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5536 def udt @udt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5544 5545 5546 5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 5558 5559 5560 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5544 def update!(**args) @array = args[:array] if args.key?(:array) @array_length = args[:array_length] if args.key?(:array_length) @auto_generated = args[:auto_generated] if args.key?(:auto_generated) @charset = args[:charset] if args.key?(:charset) @collation = args[:collation] if args.key?(:collation) @comment = args[:comment] if args.key?(:comment) @custom_features = args[:custom_features] if args.key?(:custom_features) @data_type = args[:data_type] if args.key?(:data_type) @fractional_seconds_precision = args[:fractional_seconds_precision] if args.key?(:fractional_seconds_precision) @length = args[:length] if args.key?(:length) @nullable = args[:nullable] if args.key?(:nullable) @precision = args[:precision] if args.key?(:precision) @scale = args[:scale] if args.key?(:scale) @set_values = args[:set_values] if args.key?(:set_values) @udt = args[:udt] if args.key?(:udt) end |