Class: Google::Apis::DatamigrationV1::SingleColumnChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Options to configure rule type SingleColumnChange. The rule is used to change the properties of a column. The rule filter field can refer to one entity. The rule scope can be one of: Column. When using this rule, if a field is not specified than the destination column's configuration will be the same as the one in the source column..

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleColumnChange

Returns a new instance of SingleColumnChange.



5028
5029
5030
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arrayBoolean Also known as: array?

Optional. Is the column of array type. Corresponds to the JSON property array

Returns:

  • (Boolean)


4950
4951
4952
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4950

def array
  @array
end

#array_lengthFixnum

Optional. The length of the array, only relevant if the column type is an array. Corresponds to the JSON property arrayLength

Returns:

  • (Fixnum)


4957
4958
4959
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4957

def array_length
  @array_length
end

#auto_generatedBoolean Also known as: auto_generated?

Optional. Is the column auto-generated/identity. Corresponds to the JSON property autoGenerated

Returns:

  • (Boolean)


4962
4963
4964
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4962

def auto_generated
  @auto_generated
end

#charsetString

Optional. Charset override - instead of table level charset. Corresponds to the JSON property charset

Returns:

  • (String)


4968
4969
4970
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4968

def charset
  @charset
end

#collationString

Optional. Collation override - instead of table level collation. Corresponds to the JSON property collation

Returns:

  • (String)


4973
4974
4975
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4973

def collation
  @collation
end

#commentString

Optional. Comment associated with the column. Corresponds to the JSON property comment

Returns:

  • (String)


4978
4979
4980
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4978

def comment
  @comment
end

#custom_featuresHash<String,Object>

Optional. Custom engine specific features. Corresponds to the JSON property customFeatures

Returns:

  • (Hash<String,Object>)


4983
4984
4985
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4983

def custom_features
  @custom_features
end

#data_typeString

Optional. Column data type name. Corresponds to the JSON property dataType

Returns:

  • (String)


4988
4989
4990
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4988

def data_type
  @data_type
end

#fractional_seconds_precisionFixnum

Optional. Column fractional seconds precision - e.g. 2 as in timestamp (2) - when relevant. Corresponds to the JSON property fractionalSecondsPrecision

Returns:

  • (Fixnum)


4994
4995
4996
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4994

def fractional_seconds_precision
  @fractional_seconds_precision
end

#lengthFixnum

Optional. Column length - e.g. 50 as in varchar (50) - when relevant. Corresponds to the JSON property length

Returns:

  • (Fixnum)


4999
5000
5001
# File 'lib/google/apis/datamigration_v1/classes.rb', line 4999

def length
  @length
end

#nullableBoolean Also known as: nullable?

Optional. Is the column nullable. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


5004
5005
5006
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5004

def nullable
  @nullable
end

#precisionFixnum

Optional. Column precision - e.g. 8 as in double (8,2) - when relevant. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


5010
5011
5012
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5010

def precision
  @precision
end

#scaleFixnum

Optional. Column scale - e.g. 2 as in double (8,2) - when relevant. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


5015
5016
5017
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5015

def scale
  @scale
end

#set_valuesArray<String>

Optional. Specifies the list of values allowed in the column. Corresponds to the JSON property setValues

Returns:

  • (Array<String>)


5020
5021
5022
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5020

def set_values
  @set_values
end

#udtBoolean Also known as: udt?

Optional. Is the column a UDT (User-defined Type). Corresponds to the JSON property udt

Returns:

  • (Boolean)


5025
5026
5027
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5025

def udt
  @udt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5033
5034
5035
5036
5037
5038
5039
5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5033

def update!(**args)
  @array = args[:array] if args.key?(:array)
  @array_length = args[:array_length] if args.key?(:array_length)
  @auto_generated = args[:auto_generated] if args.key?(:auto_generated)
  @charset = args[:charset] if args.key?(:charset)
  @collation = args[:collation] if args.key?(:collation)
  @comment = args[:comment] if args.key?(:comment)
  @custom_features = args[:custom_features] if args.key?(:custom_features)
  @data_type = args[:data_type] if args.key?(:data_type)
  @fractional_seconds_precision = args[:fractional_seconds_precision] if args.key?(:fractional_seconds_precision)
  @length = args[:length] if args.key?(:length)
  @nullable = args[:nullable] if args.key?(:nullable)
  @precision = args[:precision] if args.key?(:precision)
  @scale = args[:scale] if args.key?(:scale)
  @set_values = args[:set_values] if args.key?(:set_values)
  @udt = args[:udt] if args.key?(:udt)
end