Class: Google::Apis::DatamigrationV1::SingleEntityRename
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SingleEntityRename
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Options to configure rule type SingleEntityRename. The rule is used to rename an entity. The rule filter field can refer to only one entity. The rule scope can be one of: Database, Schema, Table, Column, Constraint, Index, View, Function, Stored Procedure, Materialized View, Sequence, UDT, Synonym
Instance Attribute Summary collapse
-
#new_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleEntityRename
constructor
A new instance of SingleEntityRename.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleEntityRename
Returns a new instance of SingleEntityRename.
5636 5637 5638 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_name ⇒ String
Required. The new name of the destination entity
Corresponds to the JSON property newName
5634 5635 5636 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5634 def new_name @new_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5641 5642 5643 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5641 def update!(**args) @new_name = args[:new_name] if args.key?(:new_name) end |