Class: Google::Apis::DatamigrationV1::SingleEntityRename

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Options to configure rule type SingleEntityRename. The rule is used to rename an entity. The rule filter field can refer to only one entity. The rule scope can be one of: Database, Schema, Table, Column, Constraint, Index, View, Function, Stored Procedure, Materialized View, Sequence, UDT, Synonym

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleEntityRename

Returns a new instance of SingleEntityRename.



5575
5576
5577
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_nameString

Required. The new name of the destination entity Corresponds to the JSON property newName

Returns:

  • (String)


5573
5574
5575
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5573

def new_name
  @new_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5580
5581
5582
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5580

def update!(**args)
  @new_name = args[:new_name] if args.key?(:new_name)
end