Class: Google::Apis::DatamigrationV1::SourceObjectIdentifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

An identifier for the Migration Job Object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceObjectIdentifier

Returns a new instance of SourceObjectIdentifier.



5195
5196
5197
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

Optional. The database name. This will be required only if the object uses a database name as part of its unique identifier. Corresponds to the JSON property database

Returns:

  • (String)


5176
5177
5178
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5176

def database
  @database
end

#schemaString

Optional. The schema name. This will be required only if the object uses a schema name as part of its unique identifier. Corresponds to the JSON property schema

Returns:

  • (String)


5182
5183
5184
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5182

def schema
  @schema
end

#tableString

Optional. The table name. This will be required only if the object is a level below database or schema. Corresponds to the JSON property table

Returns:

  • (String)


5188
5189
5190
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5188

def table
  @table
end

#typeString

Required. The type of the migration job object. Corresponds to the JSON property type

Returns:

  • (String)


5193
5194
5195
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5193

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5200
5201
5202
5203
5204
5205
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5200

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @schema = args[:schema] if args.key?(:schema)
  @table = args[:table] if args.key?(:table)
  @type = args[:type] if args.key?(:type)
end