Class: Google::Apis::DatamigrationV1::SourceSqlChange
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SourceSqlChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Options to configure rule type SourceSqlChange. The rule is used to alter the sql code for database entities. The rule filter field can refer to one entity. The rule scope can be: StoredProcedure, Function, Trigger, View
Instance Attribute Summary collapse
-
#sql_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceSqlChange
constructor
A new instance of SourceSqlChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceSqlChange
Returns a new instance of SourceSqlChange.
5847 5848 5849 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sql_code ⇒ String
Required. Sql code for source (stored procedure, function, trigger or view)
Corresponds to the JSON property sqlCode
5845 5846 5847 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5845 def sql_code @sql_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5852 5853 5854 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5852 def update!(**args) @sql_code = args[:sql_code] if args.key?(:sql_code) end |