Class: Google::Apis::DatamigrationV1::SourceSqlChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Options to configure rule type SourceSqlChange. The rule is used to alter the sql code for database entities. The rule filter field can refer to one entity. The rule scope can be: StoredProcedure, Function, Trigger, View

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceSqlChange

Returns a new instance of SourceSqlChange.



5747
5748
5749
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sql_codeString

Required. Sql code for source (stored procedure, function, trigger or view) Corresponds to the JSON property sqlCode

Returns:

  • (String)


5745
5746
5747
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5745

def sql_code
  @sql_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5752
5753
5754
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5752

def update!(**args)
  @sql_code = args[:sql_code] if args.key?(:sql_code)
end