Class: Google::Apis::DatamigrationV1::SqlIpConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

IP Management configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlIpConfig

Returns a new instance of SqlIpConfig.



5930
5931
5932
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_ip_rangeString

Optional. The name of the allocated IP address range for the private IP Cloud SQL instance. This name refers to an already allocated IP range address. If set, the instance IP address will be created in the allocated range. Note that this IP address range can't be modified after the instance is created. If you change the VPC when configuring connectivity settings for the migration job, this field is not relevant. Corresponds to the JSON property allocatedIpRange

Returns:

  • (String)


5901
5902
5903
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5901

def allocated_ip_range
  @allocated_ip_range
end

#authorized_networksArray<Google::Apis::DatamigrationV1::SqlAclEntry>

The list of external networks that are allowed to connect to the instance using the IP. See https://en.wikipedia.org/wiki/CIDR_notation#CIDR_notation, also known as 'slash' notation (e.g. 192.168.100.0/24). Corresponds to the JSON property authorizedNetworks



5908
5909
5910
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5908

def authorized_networks
  @authorized_networks
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Whether the instance should be assigned an IPv4 address or not. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


5913
5914
5915
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5913

def enable_ipv4
  @enable_ipv4
end

#private_networkString

The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP. For example, projects/myProject/global/networks/ default. This setting can be updated, but it cannot be removed after it is set. Corresponds to the JSON property privateNetwork

Returns:

  • (String)


5922
5923
5924
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5922

def private_network
  @private_network
end

#require_sslBoolean Also known as: require_ssl?

Whether SSL connections over IP should be enforced or not. Corresponds to the JSON property requireSsl

Returns:

  • (Boolean)


5927
5928
5929
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5927

def require_ssl
  @require_ssl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5935
5936
5937
5938
5939
5940
5941
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5935

def update!(**args)
  @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range)
  @authorized_networks = args[:authorized_networks] if args.key?(:authorized_networks)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @private_network = args[:private_network] if args.key?(:private_network)
  @require_ssl = args[:require_ssl] if args.key?(:require_ssl)
end