Class: Google::Apis::DatamigrationV1::SqlIpConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SqlIpConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
IP Management configuration.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ String
Optional.
-
#authorized_networks ⇒ Array<Google::Apis::DatamigrationV1::SqlAclEntry>
The list of external networks that are allowed to connect to the instance using the IP.
-
#enable_ipv4 ⇒ Boolean
(also: #enable_ipv4?)
Whether the instance should be assigned an IPv4 address or not.
-
#private_network ⇒ String
The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP.
-
#require_ssl ⇒ Boolean
(also: #require_ssl?)
Whether SSL connections over IP should be enforced or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlIpConfig
constructor
A new instance of SqlIpConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlIpConfig
Returns a new instance of SqlIpConfig.
5904 5905 5906 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_ip_range ⇒ String
Optional. The name of the allocated IP address range for the private IP Cloud
SQL instance. This name refers to an already allocated IP range address. If
set, the instance IP address will be created in the allocated range. Note that
this IP address range can't be modified after the instance is created. If you
change the VPC when configuring connectivity settings for the migration job,
this field is not relevant.
Corresponds to the JSON property allocatedIpRange
5875 5876 5877 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5875 def allocated_ip_range @allocated_ip_range end |
#authorized_networks ⇒ Array<Google::Apis::DatamigrationV1::SqlAclEntry>
The list of external networks that are allowed to connect to the instance
using the IP. See https://en.wikipedia.org/wiki/CIDR_notation#CIDR_notation,
also known as 'slash' notation (e.g. 192.168.100.0/24).
Corresponds to the JSON property authorizedNetworks
5882 5883 5884 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5882 def @authorized_networks end |
#enable_ipv4 ⇒ Boolean Also known as: enable_ipv4?
Whether the instance should be assigned an IPv4 address or not.
Corresponds to the JSON property enableIpv4
5887 5888 5889 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5887 def enable_ipv4 @enable_ipv4 end |
#private_network ⇒ String
The resource link for the VPC network from which the Cloud SQL instance is
accessible for private IP. For example, projects/myProject/global/networks/
default. This setting can be updated, but it cannot be removed after it is
set.
Corresponds to the JSON property privateNetwork
5896 5897 5898 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5896 def private_network @private_network end |
#require_ssl ⇒ Boolean Also known as: require_ssl?
Whether SSL connections over IP should be enforced or not.
Corresponds to the JSON property requireSsl
5901 5902 5903 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5901 def require_ssl @require_ssl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5909 5910 5911 5912 5913 5914 5915 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5909 def update!(**args) @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range) @authorized_networks = args[:authorized_networks] if args.key?(:authorized_networks) @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4) @private_network = args[:private_network] if args.key?(:private_network) @require_ssl = args[:require_ssl] if args.key?(:require_ssl) end |