Class: Google::Apis::DatamigrationV1::SqlIpConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SqlIpConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
IP Management configuration.
Instance Attribute Summary collapse
-
#allocated_ip_range ⇒ String
Optional.
-
#authorized_networks ⇒ Array<Google::Apis::DatamigrationV1::SqlAclEntry>
The list of external networks that are allowed to connect to the instance using the IP.
-
#enable_ipv4 ⇒ Boolean
(also: #enable_ipv4?)
Whether the instance should be assigned an IPv4 address or not.
-
#private_network ⇒ String
The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP.
-
#require_ssl ⇒ Boolean
(also: #require_ssl?)
Whether SSL connections over IP should be enforced or not.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlIpConfig
constructor
A new instance of SqlIpConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlIpConfig
Returns a new instance of SqlIpConfig.
5863 5864 5865 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_ip_range ⇒ String
Optional. The name of the allocated IP address range for the private IP Cloud
SQL instance. This name refers to an already allocated IP range address. If
set, the instance IP address will be created in the allocated range. Note that
this IP address range can't be modified after the instance is created. If you
change the VPC when configuring connectivity settings for the migration job,
this field is not relevant.
Corresponds to the JSON property allocatedIpRange
5834 5835 5836 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5834 def allocated_ip_range @allocated_ip_range end |
#authorized_networks ⇒ Array<Google::Apis::DatamigrationV1::SqlAclEntry>
The list of external networks that are allowed to connect to the instance
using the IP. See https://en.wikipedia.org/wiki/CIDR_notation#CIDR_notation,
also known as 'slash' notation (e.g. 192.168.100.0/24).
Corresponds to the JSON property authorizedNetworks
5841 5842 5843 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5841 def @authorized_networks end |
#enable_ipv4 ⇒ Boolean Also known as: enable_ipv4?
Whether the instance should be assigned an IPv4 address or not.
Corresponds to the JSON property enableIpv4
5846 5847 5848 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5846 def enable_ipv4 @enable_ipv4 end |
#private_network ⇒ String
The resource link for the VPC network from which the Cloud SQL instance is
accessible for private IP. For example, projects/myProject/global/networks/
default. This setting can be updated, but it cannot be removed after it is
set.
Corresponds to the JSON property privateNetwork
5855 5856 5857 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5855 def private_network @private_network end |
#require_ssl ⇒ Boolean Also known as: require_ssl?
Whether SSL connections over IP should be enforced or not.
Corresponds to the JSON property requireSsl
5860 5861 5862 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5860 def require_ssl @require_ssl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5868 def update!(**args) @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range) @authorized_networks = args[:authorized_networks] if args.key?(:authorized_networks) @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4) @private_network = args[:private_network] if args.key?(:private_network) @require_ssl = args[:require_ssl] if args.key?(:require_ssl) end |