Class: Google::Apis::DatamigrationV1::SqlServerConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for SQL Server databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerConnectionProfile

Returns a new instance of SqlServerConnectionProfile.



6064
6065
6066
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsGoogle::Apis::DatamigrationV1::SqlServerBackups

Specifies the backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server. Corresponds to the JSON property backups



5981
5982
5983
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5981

def backups
  @backups
end

#cloud_sql_idString

If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source. Corresponds to the JSON property cloudSqlId

Returns:

  • (String)


5987
5988
5989
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5987

def cloud_sql_id
  @cloud_sql_id
end

#cloud_sql_project_idString

Optional. The project id of the Cloud SQL instance. If not provided, the project id of the connection profile will be used. Corresponds to the JSON property cloudSqlProjectId

Returns:

  • (String)


5993
5994
5995
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5993

def cloud_sql_project_id
  @cloud_sql_project_id
end

#databaseString

Required. The name of the specific database within the host. Corresponds to the JSON property database

Returns:

  • (String)


5998
5999
6000
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5998

def database
  @database
end

#dbm_portFixnum

Optional. The Database Mirroring (DBM) port of the source SQL Server instance. Corresponds to the JSON property dbmPort

Returns:

  • (Fixnum)


6003
6004
6005
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6003

def dbm_port
  @dbm_port
end

#forward_ssh_connectivityGoogle::Apis::DatamigrationV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



6008
6009
6010
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6008

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#hostString

Required. The IP or hostname of the source SQL Server database. Corresponds to the JSON property host

Returns:

  • (String)


6013
6014
6015
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6013

def host
  @host
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


6021
6022
6023
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6021

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates whether a new password is included in the request. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


6026
6027
6028
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6026

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source SQL Server database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6032
6033
6034
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6032

def port
  @port
end

#private_connectivityGoogle::Apis::DatamigrationV1::PrivateConnectivity

Private Connectivity. Corresponds to the JSON property privateConnectivity



6037
6038
6039
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6037

def private_connectivity
  @private_connectivity
end

#private_service_connect_connectivityGoogle::Apis::DatamigrationV1::PrivateServiceConnectConnectivity

Private Service Connect connectivity Corresponds to the JSON property privateServiceConnectConnectivity



6043
6044
6045
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6043

def private_service_connect_connectivity
  @private_service_connect_connectivity
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



6048
6049
6050
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6048

def ssl
  @ssl
end

#static_ip_connectivityGoogle::Apis::DatamigrationV1::StaticIpConnectivity

The source database will allow incoming connections from the public IP of the destination database. You can retrieve the public IP of the Cloud SQL instance from the Cloud SQL console or using Cloud SQL APIs. No additional configuration is required. Corresponds to the JSON property staticIpConnectivity



6056
6057
6058
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6056

def static_ip_connectivity
  @static_ip_connectivity
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6062

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6069
6070
6071
6072
6073
6074
6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6069

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id)
  @cloud_sql_project_id = args[:cloud_sql_project_id] if args.key?(:cloud_sql_project_id)
  @database = args[:database] if args.key?(:database)
  @dbm_port = args[:dbm_port] if args.key?(:dbm_port)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @private_service_connect_connectivity = args[:private_service_connect_connectivity] if args.key?(:private_service_connect_connectivity)
  @ssl = args[:ssl] if args.key?(:ssl)
  @static_ip_connectivity = args[:static_ip_connectivity] if args.key?(:static_ip_connectivity)
  @username = args[:username] if args.key?(:username)
end