Class: Google::Apis::DatamigrationV1::SqlServerConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for SQL Server databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerConnectionProfile

Returns a new instance of SqlServerConnectionProfile.



6036
6037
6038
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsGoogle::Apis::DatamigrationV1::SqlServerBackups

Specifies the backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server. Corresponds to the JSON property backups



5953
5954
5955
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5953

def backups
  @backups
end

#cloud_sql_idString

If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source. Corresponds to the JSON property cloudSqlId

Returns:

  • (String)


5959
5960
5961
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5959

def cloud_sql_id
  @cloud_sql_id
end

#cloud_sql_project_idString

Optional. The project id of the Cloud SQL instance. If not provided, the project id of the connection profile will be used. Corresponds to the JSON property cloudSqlProjectId

Returns:

  • (String)


5965
5966
5967
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5965

def cloud_sql_project_id
  @cloud_sql_project_id
end

#databaseString

Required. The name of the specific database within the host. Corresponds to the JSON property database

Returns:

  • (String)


5970
5971
5972
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5970

def database
  @database
end

#dbm_portFixnum

Optional. The Database Mirroring (DBM) port of the source SQL Server instance. Corresponds to the JSON property dbmPort

Returns:

  • (Fixnum)


5975
5976
5977
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5975

def dbm_port
  @dbm_port
end

#forward_ssh_connectivityGoogle::Apis::DatamigrationV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



5980
5981
5982
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5980

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#hostString

Required. The IP or hostname of the source SQL Server database. Corresponds to the JSON property host

Returns:

  • (String)


5985
5986
5987
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5985

def host
  @host
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


5993
5994
5995
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5993

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates whether a new password is included in the request. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


5998
5999
6000
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5998

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source SQL Server database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


6004
6005
6006
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6004

def port
  @port
end

#private_connectivityGoogle::Apis::DatamigrationV1::PrivateConnectivity

Private Connectivity. Corresponds to the JSON property privateConnectivity



6009
6010
6011
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6009

def private_connectivity
  @private_connectivity
end

#private_service_connect_connectivityGoogle::Apis::DatamigrationV1::PrivateServiceConnectConnectivity

Private Service Connect connectivity Corresponds to the JSON property privateServiceConnectConnectivity



6015
6016
6017
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6015

def private_service_connect_connectivity
  @private_service_connect_connectivity
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



6020
6021
6022
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6020

def ssl
  @ssl
end

#static_ip_connectivityGoogle::Apis::DatamigrationV1::StaticIpConnectivity

The source database will allow incoming connections from the public IP of the destination database. You can retrieve the public IP of the Cloud SQL instance from the Cloud SQL console or using Cloud SQL APIs. No additional configuration is required. Corresponds to the JSON property staticIpConnectivity



6028
6029
6030
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6028

def static_ip_connectivity
  @static_ip_connectivity
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


6034
6035
6036
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6034

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6041
6042
6043
6044
6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6041

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id)
  @cloud_sql_project_id = args[:cloud_sql_project_id] if args.key?(:cloud_sql_project_id)
  @database = args[:database] if args.key?(:database)
  @dbm_port = args[:dbm_port] if args.key?(:dbm_port)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @private_service_connect_connectivity = args[:private_service_connect_connectivity] if args.key?(:private_service_connect_connectivity)
  @ssl = args[:ssl] if args.key?(:ssl)
  @static_ip_connectivity = args[:static_ip_connectivity] if args.key?(:static_ip_connectivity)
  @username = args[:username] if args.key?(:username)
end