Class: Google::Apis::DatamigrationV1::SqlServerConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Specifies connection parameters required specifically for SQL Server databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerConnectionProfile

Returns a new instance of SqlServerConnectionProfile.



5995
5996
5997
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupsGoogle::Apis::DatamigrationV1::SqlServerBackups

Specifies the backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server. Corresponds to the JSON property backups



5912
5913
5914
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5912

def backups
  @backups
end

#cloud_sql_idString

If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source. Corresponds to the JSON property cloudSqlId

Returns:

  • (String)


5918
5919
5920
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5918

def cloud_sql_id
  @cloud_sql_id
end

#cloud_sql_project_idString

Optional. The project id of the Cloud SQL instance. If not provided, the project id of the connection profile will be used. Corresponds to the JSON property cloudSqlProjectId

Returns:

  • (String)


5924
5925
5926
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5924

def cloud_sql_project_id
  @cloud_sql_project_id
end

#databaseString

Required. The name of the specific database within the host. Corresponds to the JSON property database

Returns:

  • (String)


5929
5930
5931
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5929

def database
  @database
end

#dbm_portFixnum

Optional. The Database Mirroring (DBM) port of the source SQL Server instance. Corresponds to the JSON property dbmPort

Returns:

  • (Fixnum)


5934
5935
5936
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5934

def dbm_port
  @dbm_port
end

#forward_ssh_connectivityGoogle::Apis::DatamigrationV1::ForwardSshTunnelConnectivity

Forward SSH Tunnel connectivity. Corresponds to the JSON property forwardSshConnectivity



5939
5940
5941
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5939

def forward_ssh_connectivity
  @forward_ssh_connectivity
end

#hostString

Required. The IP or hostname of the source SQL Server database. Corresponds to the JSON property host

Returns:

  • (String)


5944
5945
5946
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5944

def host
  @host
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


5952
5953
5954
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5952

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates whether a new password is included in the request. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


5957
5958
5959
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5957

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source SQL Server database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


5963
5964
5965
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5963

def port
  @port
end

#private_connectivityGoogle::Apis::DatamigrationV1::PrivateConnectivity

Private Connectivity. Corresponds to the JSON property privateConnectivity



5968
5969
5970
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5968

def private_connectivity
  @private_connectivity
end

#private_service_connect_connectivityGoogle::Apis::DatamigrationV1::PrivateServiceConnectConnectivity

Private Service Connect connectivity Corresponds to the JSON property privateServiceConnectConnectivity



5974
5975
5976
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5974

def private_service_connect_connectivity
  @private_service_connect_connectivity
end

#sslGoogle::Apis::DatamigrationV1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



5979
5980
5981
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5979

def ssl
  @ssl
end

#static_ip_connectivityGoogle::Apis::DatamigrationV1::StaticIpConnectivity

The source database will allow incoming connections from the public IP of the destination database. You can retrieve the public IP of the Cloud SQL instance from the Cloud SQL console or using Cloud SQL APIs. No additional configuration is required. Corresponds to the JSON property staticIpConnectivity



5987
5988
5989
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5987

def static_ip_connectivity
  @static_ip_connectivity
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


5993
5994
5995
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5993

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6000
6001
6002
6003
6004
6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6000

def update!(**args)
  @backups = args[:backups] if args.key?(:backups)
  @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id)
  @cloud_sql_project_id = args[:cloud_sql_project_id] if args.key?(:cloud_sql_project_id)
  @database = args[:database] if args.key?(:database)
  @dbm_port = args[:dbm_port] if args.key?(:dbm_port)
  @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity)
  @private_service_connect_connectivity = args[:private_service_connect_connectivity] if args.key?(:private_service_connect_connectivity)
  @ssl = args[:ssl] if args.key?(:ssl)
  @static_ip_connectivity = args[:static_ip_connectivity] if args.key?(:static_ip_connectivity)
  @username = args[:username] if args.key?(:username)
end