Class: Google::Apis::DatamigrationV1::SqlServerConnectionProfile
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SqlServerConnectionProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Specifies connection parameters required specifically for SQL Server databases.
Instance Attribute Summary collapse
-
#backups ⇒ Google::Apis::DatamigrationV1::SqlServerBackups
Specifies the backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server.
-
#cloud_sql_id ⇒ String
If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source.
-
#cloud_sql_project_id ⇒ String
Optional.
-
#database ⇒ String
Required.
-
#dbm_port ⇒ Fixnum
Optional.
-
#forward_ssh_connectivity ⇒ Google::Apis::DatamigrationV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
-
#host ⇒ String
Required.
-
#password ⇒ String
Required.
-
#password_set ⇒ Boolean
(also: #password_set?)
Output only.
-
#port ⇒ Fixnum
Required.
-
#private_connectivity ⇒ Google::Apis::DatamigrationV1::PrivateConnectivity
Private Connectivity.
-
#private_service_connect_connectivity ⇒ Google::Apis::DatamigrationV1::PrivateServiceConnectConnectivity
Private Service Connect connectivity Corresponds to the JSON property
privateServiceConnectConnectivity. -
#ssl ⇒ Google::Apis::DatamigrationV1::SslConfig
SSL configuration information.
-
#static_ip_connectivity ⇒ Google::Apis::DatamigrationV1::StaticIpConnectivity
The source database will allow incoming connections from the public IP of the destination database.
-
#username ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerConnectionProfile
constructor
A new instance of SqlServerConnectionProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerConnectionProfile
Returns a new instance of SqlServerConnectionProfile.
5492 5493 5494 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Google::Apis::DatamigrationV1::SqlServerBackups
Specifies the backup details in Cloud Storage for homogeneous migration to
Cloud SQL for SQL Server.
Corresponds to the JSON property backups
5409 5410 5411 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5409 def backups @backups end |
#cloud_sql_id ⇒ String
If the source is a Cloud SQL database, use this field to provide the Cloud SQL
instance ID of the source.
Corresponds to the JSON property cloudSqlId
5415 5416 5417 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5415 def cloud_sql_id @cloud_sql_id end |
#cloud_sql_project_id ⇒ String
Optional. The project id of the Cloud SQL instance. If not provided, the
project id of the connection profile will be used.
Corresponds to the JSON property cloudSqlProjectId
5421 5422 5423 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5421 def cloud_sql_project_id @cloud_sql_project_id end |
#database ⇒ String
Required. The name of the specific database within the host.
Corresponds to the JSON property database
5426 5427 5428 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5426 def database @database end |
#dbm_port ⇒ Fixnum
Optional. The Database Mirroring (DBM) port of the source SQL Server instance.
Corresponds to the JSON property dbmPort
5431 5432 5433 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5431 def dbm_port @dbm_port end |
#forward_ssh_connectivity ⇒ Google::Apis::DatamigrationV1::ForwardSshTunnelConnectivity
Forward SSH Tunnel connectivity.
Corresponds to the JSON property forwardSshConnectivity
5436 5437 5438 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5436 def forward_ssh_connectivity @forward_ssh_connectivity end |
#host ⇒ String
Required. The IP or hostname of the source SQL Server database.
Corresponds to the JSON property host
5441 5442 5443 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5441 def host @host end |
#password ⇒ String
Required. Input only. The password for the user that Database Migration
Service will be using to connect to the database. This field is not returned
on request, and the value is encrypted when stored in Database Migration
Service.
Corresponds to the JSON property password
5449 5450 5451 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5449 def password @password end |
#password_set ⇒ Boolean Also known as: password_set?
Output only. Indicates whether a new password is included in the request.
Corresponds to the JSON property passwordSet
5454 5455 5456 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5454 def password_set @password_set end |
#port ⇒ Fixnum
Required. The network port of the source SQL Server database.
Corresponds to the JSON property port
5460 5461 5462 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5460 def port @port end |
#private_connectivity ⇒ Google::Apis::DatamigrationV1::PrivateConnectivity
Private Connectivity.
Corresponds to the JSON property privateConnectivity
5465 5466 5467 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5465 def private_connectivity @private_connectivity end |
#private_service_connect_connectivity ⇒ Google::Apis::DatamigrationV1::PrivateServiceConnectConnectivity
Private Service Connect connectivity
Corresponds to the JSON property privateServiceConnectConnectivity
5471 5472 5473 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5471 def private_service_connect_connectivity @private_service_connect_connectivity end |
#ssl ⇒ Google::Apis::DatamigrationV1::SslConfig
SSL configuration information.
Corresponds to the JSON property ssl
5476 5477 5478 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5476 def ssl @ssl end |
#static_ip_connectivity ⇒ Google::Apis::DatamigrationV1::StaticIpConnectivity
The source database will allow incoming connections from the public IP of the
destination database. You can retrieve the public IP of the Cloud SQL instance
from the Cloud SQL console or using Cloud SQL APIs. No additional
configuration is required.
Corresponds to the JSON property staticIpConnectivity
5484 5485 5486 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5484 def static_ip_connectivity @static_ip_connectivity end |
#username ⇒ String
Required. The username that Database Migration Service will use to connect to
the database. The value is encrypted when stored in Database Migration Service.
Corresponds to the JSON property username
5490 5491 5492 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5490 def username @username end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5497 def update!(**args) @backups = args[:backups] if args.key?(:backups) @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id) @cloud_sql_project_id = args[:cloud_sql_project_id] if args.key?(:cloud_sql_project_id) @database = args[:database] if args.key?(:database) @dbm_port = args[:dbm_port] if args.key?(:dbm_port) @forward_ssh_connectivity = args[:forward_ssh_connectivity] if args.key?(:forward_ssh_connectivity) @host = args[:host] if args.key?(:host) @password = args[:password] if args.key?(:password) @password_set = args[:password_set] if args.key?(:password_set) @port = args[:port] if args.key?(:port) @private_connectivity = args[:private_connectivity] if args.key?(:private_connectivity) @private_service_connect_connectivity = args[:private_service_connect_connectivity] if args.key?(:private_service_connect_connectivity) @ssl = args[:ssl] if args.key?(:ssl) @static_ip_connectivity = args[:static_ip_connectivity] if args.key?(:static_ip_connectivity) @username = args[:username] if args.key?(:username) end |