Class: Google::Apis::DatamigrationV1::SqlServerSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Configuration for SQL Server as a source in a migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerSourceConfig

Returns a new instance of SqlServerSourceConfig.



6285
6286
6287
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cdc_start_positionString

Optional. The log sequence number (LSN) to start CDC data migration from. Corresponds to the JSON property cdcStartPosition

Returns:

  • (String)


6265
6266
6267
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6265

def cdc_start_position
  @cdc_start_position
end

#max_concurrent_cdc_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for CDC phase. Corresponds to the JSON property maxConcurrentCdcConnections

Returns:

  • (Fixnum)


6271
6272
6273
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6271

def max_concurrent_cdc_connections
  @max_concurrent_cdc_connections
end

#max_concurrent_full_dump_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for full dump phase. Corresponds to the JSON property maxConcurrentFullDumpConnections

Returns:

  • (Fixnum)


6277
6278
6279
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6277

def max_concurrent_full_dump_connections
  @max_concurrent_full_dump_connections
end

#skip_full_dumpBoolean Also known as: skip_full_dump?

Optional. Whether to skip full dump or not. Corresponds to the JSON property skipFullDump

Returns:

  • (Boolean)


6282
6283
6284
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6282

def skip_full_dump
  @skip_full_dump
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6290
6291
6292
6293
6294
6295
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6290

def update!(**args)
  @cdc_start_position = args[:cdc_start_position] if args.key?(:cdc_start_position)
  @max_concurrent_cdc_connections = args[:max_concurrent_cdc_connections] if args.key?(:max_concurrent_cdc_connections)
  @max_concurrent_full_dump_connections = args[:max_concurrent_full_dump_connections] if args.key?(:max_concurrent_full_dump_connections)
  @skip_full_dump = args[:skip_full_dump] if args.key?(:skip_full_dump)
end