Class: Google::Apis::DatamigrationV1::SqlServerSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Configuration for SQL Server as a source in a migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerSourceConfig

Returns a new instance of SqlServerSourceConfig.



6216
6217
6218
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cdc_start_positionString

Optional. The log sequence number (LSN) to start CDC data migration from. Corresponds to the JSON property cdcStartPosition

Returns:

  • (String)


6196
6197
6198
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6196

def cdc_start_position
  @cdc_start_position
end

#max_concurrent_cdc_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for CDC phase. Corresponds to the JSON property maxConcurrentCdcConnections

Returns:

  • (Fixnum)


6202
6203
6204
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6202

def max_concurrent_cdc_connections
  @max_concurrent_cdc_connections
end

#max_concurrent_full_dump_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for full dump phase. Corresponds to the JSON property maxConcurrentFullDumpConnections

Returns:

  • (Fixnum)


6208
6209
6210
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6208

def max_concurrent_full_dump_connections
  @max_concurrent_full_dump_connections
end

#skip_full_dumpBoolean Also known as: skip_full_dump?

Optional. Whether to skip full dump or not. Corresponds to the JSON property skipFullDump

Returns:

  • (Boolean)


6213
6214
6215
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6213

def skip_full_dump
  @skip_full_dump
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6221
6222
6223
6224
6225
6226
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6221

def update!(**args)
  @cdc_start_position = args[:cdc_start_position] if args.key?(:cdc_start_position)
  @max_concurrent_cdc_connections = args[:max_concurrent_cdc_connections] if args.key?(:max_concurrent_cdc_connections)
  @max_concurrent_full_dump_connections = args[:max_concurrent_full_dump_connections] if args.key?(:max_concurrent_full_dump_connections)
  @skip_full_dump = args[:skip_full_dump] if args.key?(:skip_full_dump)
end