Class: Google::Apis::DatamigrationV1::SqlServerSourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

Configuration for SQL Server as a source in a migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlServerSourceConfig

Returns a new instance of SqlServerSourceConfig.



5713
5714
5715
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cdc_start_positionString

Optional. The log sequence number (LSN) to start CDC data migration from. Corresponds to the JSON property cdcStartPosition

Returns:

  • (String)


5693
5694
5695
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5693

def cdc_start_position
  @cdc_start_position
end

#max_concurrent_cdc_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for CDC phase. Corresponds to the JSON property maxConcurrentCdcConnections

Returns:

  • (Fixnum)


5699
5700
5701
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5699

def max_concurrent_cdc_connections
  @max_concurrent_cdc_connections
end

#max_concurrent_full_dump_connectionsFixnum

Optional. Maximum number of connections Database Migration Service will open to the source for full dump phase. Corresponds to the JSON property maxConcurrentFullDumpConnections

Returns:

  • (Fixnum)


5705
5706
5707
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5705

def max_concurrent_full_dump_connections
  @max_concurrent_full_dump_connections
end

#skip_full_dumpBoolean Also known as: skip_full_dump?

Optional. Whether to skip full dump or not. Corresponds to the JSON property skipFullDump

Returns:

  • (Boolean)


5710
5711
5712
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5710

def skip_full_dump
  @skip_full_dump
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5718
5719
5720
5721
5722
5723
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5718

def update!(**args)
  @cdc_start_position = args[:cdc_start_position] if args.key?(:cdc_start_position)
  @max_concurrent_cdc_connections = args[:max_concurrent_cdc_connections] if args.key?(:max_concurrent_cdc_connections)
  @max_concurrent_full_dump_connections = args[:max_concurrent_full_dump_connections] if args.key?(:max_concurrent_full_dump_connections)
  @skip_full_dump = args[:skip_full_dump] if args.key?(:skip_full_dump)
end