Class: Google::Apis::DatamigrationV1::SqlServerToPostgresConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::SqlServerToPostgresConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
Configuration for heterogeneous SQL Server to Cloud SQL for PostgreSQL migrations.
Instance Attribute Summary collapse
-
#postgres_destination_config ⇒ Google::Apis::DatamigrationV1::PostgresDestinationConfig
Configuration for Postgres as a destination in a migration.
-
#sqlserver_source_config ⇒ Google::Apis::DatamigrationV1::SqlServerSourceConfig
Configuration for SQL Server as a source in a migration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlServerToPostgresConfig
constructor
A new instance of SqlServerToPostgresConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlServerToPostgresConfig
Returns a new instance of SqlServerToPostgresConfig.
5741 5742 5743 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#postgres_destination_config ⇒ Google::Apis::DatamigrationV1::PostgresDestinationConfig
Configuration for Postgres as a destination in a migration.
Corresponds to the JSON property postgresDestinationConfig
5734 5735 5736 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5734 def postgres_destination_config @postgres_destination_config end |
#sqlserver_source_config ⇒ Google::Apis::DatamigrationV1::SqlServerSourceConfig
Configuration for SQL Server as a source in a migration.
Corresponds to the JSON property sqlserverSourceConfig
5739 5740 5741 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5739 def sqlserver_source_config @sqlserver_source_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5746 5747 5748 5749 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 5746 def update!(**args) @postgres_destination_config = args[:postgres_destination_config] if args.key?(:postgres_destination_config) @sqlserver_source_config = args[:sqlserver_source_config] if args.key?(:sqlserver_source_config) end |