Class: Google::Apis::DatamigrationV1::SslConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

SSL configuration information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslConfig

Returns a new instance of SslConfig.



6321
6322
6323
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

Required. Input only. The x509 PEM-encoded certificate of the CA that signed the source database server's certificate. The replica will use this certificate to verify it's connecting to the right host. Corresponds to the JSON property caCertificate

Returns:

  • (String)


6291
6292
6293
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6291

def ca_certificate
  @ca_certificate
end

#client_certificateString

Input only. The x509 PEM-encoded certificate that will be used by the replica to authenticate against the source database server.If this field is used then the 'client_key' field is mandatory. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


6298
6299
6300
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6298

def client_certificate
  @client_certificate
end

#client_keyString

Input only. The unencrypted PKCS#1 or PKCS#8 PEM-encoded private key associated with the Client Certificate. If this field is used then the ' client_certificate' field is mandatory. Corresponds to the JSON property clientKey

Returns:

  • (String)


6305
6306
6307
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6305

def client_key
  @client_key
end

#ssl_flagsHash<String,String>

Optional. SSL flags used for establishing SSL connection to the source database. Only source specific flags are supported. An object containing a list of "key": "value" pairs. Example: "server_certificate_hostname": " server.com". Corresponds to the JSON property sslFlags

Returns:

  • (Hash<String,String>)


6313
6314
6315
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6313

def ssl_flags
  @ssl_flags
end

#typeString

Optional. The ssl config type according to 'client_key', 'client_certificate' and 'ca_certificate'. Corresponds to the JSON property type

Returns:

  • (String)


6319
6320
6321
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6319

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6326
6327
6328
6329
6330
6331
6332
# File 'lib/google/apis/datamigration_v1/classes.rb', line 6326

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_key = args[:client_key] if args.key?(:client_key)
  @ssl_flags = args[:ssl_flags] if args.key?(:ssl_flags)
  @type = args[:type] if args.key?(:type)
end