Class: Google::Apis::DatamigrationV1::VpcPeeringConnectivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb

Overview

The details of the VPC where the source database is located in Google Cloud. We will use this information to set up the VPC peering connection between Cloud SQL and this VPC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpcPeeringConnectivity

Returns a new instance of VpcPeeringConnectivity.



7040
7041
7042
# File 'lib/google/apis/datamigration_v1/classes.rb', line 7040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#vpcString

The name of the VPC network to peer with the Cloud SQL private network. Corresponds to the JSON property vpc

Returns:

  • (String)


7038
7039
7040
# File 'lib/google/apis/datamigration_v1/classes.rb', line 7038

def vpc
  @vpc
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7045
7046
7047
# File 'lib/google/apis/datamigration_v1/classes.rb', line 7045

def update!(**args)
  @vpc = args[:vpc] if args.key?(:vpc)
end