Class: Google::Apis::DatamigrationV1::VpcPeeringConnectivity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1::VpcPeeringConnectivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1/classes.rb,
lib/google/apis/datamigration_v1/representations.rb,
lib/google/apis/datamigration_v1/representations.rb
Overview
The details of the VPC where the source database is located in Google Cloud. We will use this information to set up the VPC peering connection between Cloud SQL and this VPC.
Instance Attribute Summary collapse
-
#vpc ⇒ String
The name of the VPC network to peer with the Cloud SQL private network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpcPeeringConnectivity
constructor
A new instance of VpcPeeringConnectivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpcPeeringConnectivity
Returns a new instance of VpcPeeringConnectivity.
7038 7039 7040 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 7038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#vpc ⇒ String
The name of the VPC network to peer with the Cloud SQL private network.
Corresponds to the JSON property vpc
7036 7037 7038 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 7036 def vpc @vpc end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7043 7044 7045 |
# File 'lib/google/apis/datamigration_v1/classes.rb', line 7043 def update!(**args) @vpc = args[:vpc] if args.key?(:vpc) end |